// File           : Form1.cs 
// Original Author: Guy Smith-Ferrier
// Date Created   : September 2005
// Notes          : This file is part of the downloadable source code for .NET Internationalization, by
//                  Guy Smith-Ferrier, published by Addison-Wesley. See http://www.dotneti18n.com for details.
// Disclaimer     : No warranty is provided. Use at your own risk.
// Modification   : You are free to modify this code providing that this block of comments is not altered
//                  and is placed before any code.
using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Text;
using System.Windows.Forms;
using System.Threading;
using System.Globalization;
using Exceptions;

namespace ExceptionMessages
{
    /// <summary>
    /// Form1 is the main form showing exception messages for different cultures
    /// </summary>
    public partial class Form1 : Form
    {
        /// <summary>
        /// Constructs a Form1 object
        /// </summary>
        public Form1()
        {
            InitializeComponent();

            // initialize the correct radio button
            string cultureName = Thread.CurrentThread.CurrentUICulture.Name;
            if (cultureName == "en-US")
                radioButton1.Checked = true;
            else if (cultureName == "fr-FR")
                radioButton2.Checked = true;
            else if (cultureName == "de-DE")
                radioButton3.Checked = true;
            else if (cultureName == "es-ES")
                radioButton4.Checked = true;
        }

        private void ShowMessage(string message)
        {
            textBoxMessages.Text += message + System.Environment.NewLine;
        }

        private void button1_Click(object sender, EventArgs e)
        {
            Exception exception = new ArgumentException("Value does not fall within the expected range");
            ShowMessage(exception.Message);
        }

        private void button2_Click(object sender, EventArgs e)
        {
            Exception exception = new ArgumentException();
            ShowMessage(exception.Message);
        }

        private void button3_Click(object sender, EventArgs e)
        {
            Exception exception = new ArgumentException(null);
            ShowMessage(exception.Message);
        }

        private void button4_Click(object sender, EventArgs e)
        {
            ExceptionFactory.ExceptionCulture = new CultureInfo("en-US");
            Exception exception = ExceptionFactory.CreateException(typeof(ArgumentException));
            ShowMessage(exception.Message);
        }

        private void button5_Click(object sender, EventArgs e)
        {
            ExceptionFactory.ExceptionCulture = new CultureInfo("fr-FR");
            Exception exception = ExceptionFactory.CreateException(typeof(ArgumentException));
            ShowMessage(exception.Message);
        }

        private void radioButton1_CheckedChanged(object sender, EventArgs e)
        {
            Thread.CurrentThread.CurrentUICulture = new CultureInfo("en-US");
        }

        private void radioButton2_CheckedChanged(object sender, EventArgs e)
        {
            Thread.CurrentThread.CurrentUICulture = new CultureInfo("fr-FR");
        }

        private void radioButton3_CheckedChanged(object sender, EventArgs e)
        {
            Thread.CurrentThread.CurrentUICulture = new CultureInfo("de-DE");
        }

        private void radioButton4_CheckedChanged(object sender, EventArgs e)
        {
            Thread.CurrentThread.CurrentUICulture = new CultureInfo("es-ES");
        }

        private void button6_Click(object sender, EventArgs e)
        {
            Exception exception = new ArgumentException();
            ShowMessage(exception.Message);
            ShowMessage(ExceptionEx.FallbackException(exception).Message);
        }
    }
}