﻿// File           : BengaliBangladeshCustomCulture.cs 
// Original Author: Guy Smith-Ferrier
// Date Created   : September 2005
// Notes          : This file is part of the downloadable source code for .NET Internationalization, by
//                  Guy Smith-Ferrier, published by Addison-Wesley. See http://www.dotneti18n.com for details.
// Disclaimer     : No warranty is provided. Use at your own risk.
// Modification   : You are free to modify this code providing that this block of comments is not altered
//                  and is placed before any code.
using System;
using System.Collections.Generic;
using System.Text;
using System.Globalization;

namespace Globalization
{
    /// <summary>
    /// BengaliBangladeshCustomCulture is a custom culture helper class for the Bengali (Bangladesh) culture
    /// </summary>
	public class BengaliBangladeshCustomCulture
	{
        /// <summary>
        /// Registers the Bengali (Bangladesh) culture
        /// </summary>
		public static void RegisterBengaliBangladeshCulture()
		{
			CreateBengaliBangladeshCultureAndRegionInfoBuilder().Register();
		}
        /// <summary>
        /// Creates a CultureAndRegionInfoBuilder object for the Bengali (Bangladesh) culture
        /// </summary>
        /// <returns>A CultureAndRegionInfoBuilder object for the Bengali (Bangladesh) culture</returns>
		public static CultureAndRegionInfoBuilder CreateBengaliBangladeshCultureAndRegionInfoBuilder()
		{
			CultureAndRegionInfoBuilder builder = new CultureAndRegionInfoBuilder("bn-BD",
				CultureAndRegionModifiers.None);

			builder.Parent = CultureInfo.InvariantCulture;

			builder.CultureEnglishName = "Bengali (Bangladesh)";
			builder.CultureNativeName = "বাঙলা (Bāγlādesh)";
			builder.ThreeLetterISOLanguageName = "ben";
			builder.ThreeLetterWindowsLanguageName = "ben";
			builder.TwoLetterISOLanguageName = "bn";

			builder.RegionEnglishName = "Bangladesh";
			builder.RegionNativeName = "Bāγlādesh";
			builder.ThreeLetterISORegionName = "BGD";
			builder.ThreeLetterWindowsRegionName = "BGD";
			builder.TwoLetterISORegionName = "BD";

			builder.IetfLanguageTag = "bn-BD";

			builder.IsMetric = true;
			builder.KeyboardLayoutId = 1081;
			builder.GeoId = 0x17; // Bangladesh

			builder.GregorianDateTimeFormat = CreateBangladeshDateTimeFormatInfo();
			builder.AvailableCalendars = new Calendar[] { builder.GregorianDateTimeFormat.Calendar };

			builder.NumberFormat = CreateBangladeshNumberFormatInfo();
			builder.CurrencyEnglishName = "Bangladesh Taka";
			builder.CurrencyNativeName = "Bangladesh Taka";
			builder.ISOCurrencySymbol = "BDT";

			builder.TextInfo = CultureInfo.InvariantCulture.TextInfo;
			builder.CompareInfo = CultureInfo.InvariantCulture.CompareInfo;

			return builder;
		}
		private static NumberFormatInfo CreateBangladeshNumberFormatInfo()
		{
			NumberFormatInfo numberFormatInfo = new NumberFormatInfo();
			numberFormatInfo.CurrencyDecimalDigits = 2;
			numberFormatInfo.CurrencyDecimalSeparator = ".";
			numberFormatInfo.CurrencyGroupSeparator = ",";
			numberFormatInfo.CurrencyGroupSizes = new int[] { 3, 2 };
			numberFormatInfo.CurrencyNegativePattern = 12;
			numberFormatInfo.CurrencyPositivePattern = 2;
			numberFormatInfo.CurrencySymbol = "BDT";
			numberFormatInfo.DigitSubstitution = DigitShapes.None;
			numberFormatInfo.NaNSymbol = "NaN";
			numberFormatInfo.NativeDigits = new string[] { "০", "১", "২", "৩", "৪", "৫", "৬", "৭", "৮", "৯" };
			numberFormatInfo.NegativeInfinitySymbol = "-Infinity";
			numberFormatInfo.NegativeSign = "-";
			numberFormatInfo.NumberDecimalDigits = 2;
			numberFormatInfo.NumberDecimalSeparator = ".";
			numberFormatInfo.NumberGroupSeparator = ",";
			numberFormatInfo.NumberGroupSizes = new int[] { 3, 2 };
			numberFormatInfo.NumberNegativePattern = 1;
			numberFormatInfo.PercentDecimalDigits = 2;
			numberFormatInfo.PercentDecimalSeparator = ".";
			numberFormatInfo.PercentGroupSeparator = ",";
			numberFormatInfo.PercentGroupSizes = new int[] { 3, 2 };
			numberFormatInfo.PercentNegativePattern = 0;
			numberFormatInfo.PercentPositivePattern = 0;
			numberFormatInfo.PercentSymbol = "%";
			numberFormatInfo.PerMilleSymbol = "‰";
			numberFormatInfo.PositiveInfinitySymbol = "Infinity";
			numberFormatInfo.PositiveSign = "+";
			return numberFormatInfo;
		}
		private static DateTimeFormatInfo CreateBangladeshDateTimeFormatInfo()
		{
			Calendar calendar = new GregorianCalendar(GregorianCalendarTypes.Localized);
			DateTimeFormatInfo dateTimeFormatInfo = new DateTimeFormatInfo();
			dateTimeFormatInfo.Calendar = calendar;

			dateTimeFormatInfo.AbbreviatedDayNames = new string[] { "রবি.", "সোম.", "মঙ্গল.", "বুধ.", "বৃহস্পতি.", "শুক্র.", "শফি." };
			dateTimeFormatInfo.DayNames = new string[] { "রবিবার", "সোমবার", "মঙ্গলবার", "বুধবার", "বৃহস্পতিবার", "শুক্রবার", "শফিবার" };
			dateTimeFormatInfo.ShortestDayNames = new string[] { "রবি.", "সোম.", "মঙ্গল.", "বুধ.", "বৃহস্পতি.", "শুক্র.", "শফি." };

			dateTimeFormatInfo.AbbreviatedMonthNames = new string[] { 
				"জানু.", "ফেব্রু.", "মার্চ", "এপ্রিল", "মে", "জুন", "জুলাই", "আগ.", "সেপ্টে.", "অক্টো.", "নভে.", "ডিসে.", "" };
			dateTimeFormatInfo.MonthNames = new string[] { 
				"জানুয়ারী", "ফেব্রুয়ারী", "মার্চ", "এপ্রিল", "মে", "জুন", "জুলাই", "আগস্ট", "সেপ্টেম্বর", "অক্টোবর", "নভেম্বর", "ডিসেম্বর", "" };

			dateTimeFormatInfo.AbbreviatedMonthGenitiveNames = new string[] { 
				"জানু.", "ফেব্রু.", "মার্চ", "এপ্রিল", "মে", "জুন", "জুলাই", "আগ.", "সেপ্টে.", "অক্টো.", "নভে.", "ডিসে.", "" };
			dateTimeFormatInfo.MonthGenitiveNames = new string[] { 
				"জানুয়ারী", "ফেব্রুয়ারী", "মার্চ", "এপ্রিল", "মে", "জুন", "জুলাই", "আগস্ট", "সেপ্টেম্বর", "অক্টোবর", "নভেম্বর", "ডিসেম্বর", "" };

			dateTimeFormatInfo.AMDesignator = "পুর্বাহ্ফ";
			dateTimeFormatInfo.CalendarWeekRule = CalendarWeekRule.FirstDay;
			dateTimeFormatInfo.DateSeparator = "-";
			dateTimeFormatInfo.FirstDayOfWeek = DayOfWeek.Monday;
			dateTimeFormatInfo.FullDateTimePattern = "dd MMMM yyyy HH:mm:ss";
			dateTimeFormatInfo.LongDatePattern = "dd MMMM yyyy";
			dateTimeFormatInfo.LongTimePattern = "HH:mm:ss";
			dateTimeFormatInfo.MonthDayPattern = "dd MMMM";
			dateTimeFormatInfo.PMDesignator = "অপরাহ্ফ";
			dateTimeFormatInfo.ShortDatePattern = "dd-MM-yyyy";
			dateTimeFormatInfo.ShortTimePattern = "HH:mm";
			dateTimeFormatInfo.TimeSeparator = ":";
			dateTimeFormatInfo.YearMonthPattern = "MMMM, yyyy";

			return dateTimeFormatInfo;
		}
	}
}
