﻿// File           : Form1.cs
// Original Author: Guy Smith-Ferrier
// Date Created   : September 2005
// Notes          : This file is part of the downloadable source code for .NET Internationalization, by
//                  Guy Smith-Ferrier, published by Addison-Wesley. See http://www.dotneti18n.com for details.
// Disclaimer     : No warranty is provided. Use at your own risk.
// Modification   : You are free to modify this code providing that this block of comments is not altered
//                  and is placed before any code.
using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Text;
using System.Windows.Forms;
using System.Globalization;
using Globalization;

namespace CustomCultureExamples
{
    /// <summary>
    /// Form1 is the main demo form
    /// </summary>
	public partial class Form1 : Form
	{
        /// <summary>
        /// Constructs a Form1 object
        /// </summary>
		public Form1()
		{
			InitializeComponent();
		}

		private void ShowCulture(CultureInfo cultureInfo)
		{
			ShowCulture(cultureInfo, new RegionInfo(cultureInfo.Name));
		}

		private void ShowCulture(CultureInfo cultureInfo, RegionInfo regionInfo)
		{
			textBoxInfo.Text = String.Empty;
			textBoxInfo.Text += "CultureInfo.Name: " + cultureInfo.Name + System.Environment.NewLine;
			textBoxInfo.Text += "CultureInfo.EnglishName: " + cultureInfo.EnglishName + System.Environment.NewLine;
			textBoxInfo.Text += "CultureInfo.DisplayName: " + cultureInfo.DisplayName + System.Environment.NewLine;
			textBoxInfo.Text += "CultureInfo.NativeName: " + cultureInfo.NativeName + System.Environment.NewLine;
			textBoxInfo.Text += "CultureInfo.NumberFormat.CurrencySymbol: " + cultureInfo.NumberFormat.CurrencySymbol + System.Environment.NewLine;
			textBoxInfo.Text += "RegionInfo.CurrencyEnglishName: " + regionInfo.CurrencyEnglishName + System.Environment.NewLine;
			textBoxInfo.Text += "RegionInfo.CurrencyNativeName: " + regionInfo.CurrencyNativeName + System.Environment.NewLine;
			textBoxInfo.Text += "CultureInfo.ThreeLetterISOLanguageName: " + cultureInfo.ThreeLetterISOLanguageName + System.Environment.NewLine;
			textBoxInfo.Text += "CultureInfo.ThreeLetterWindowsLanguageName: " + cultureInfo.ThreeLetterWindowsLanguageName + System.Environment.NewLine;
			textBoxInfo.Text += "CultureInfo.TwoLetterISOLanguageName: " + cultureInfo.TwoLetterISOLanguageName + System.Environment.NewLine;
			textBoxInfo.Text += "RegionInfo.EnglishName: " + regionInfo.EnglishName + System.Environment.NewLine;
			textBoxInfo.Text += "RegionInfo.DisplayName: " + regionInfo.DisplayName + System.Environment.NewLine;
			textBoxInfo.Text += "RegionInfo.Name: " + regionInfo.Name + System.Environment.NewLine;
			textBoxInfo.Text += "RegionInfo.NativeName: " + regionInfo.NativeName + System.Environment.NewLine;
			textBoxInfo.Text += "RegionInfo.ThreeLetterISORegionName: " + regionInfo.ThreeLetterISORegionName + System.Environment.NewLine;
			textBoxInfo.Text += "RegionInfo.ThreeLetterWindowsRegionName: " + regionInfo.ThreeLetterWindowsRegionName + System.Environment.NewLine;
			textBoxInfo.Text += "RegionInfo.TwoLetterISORegionName: " + regionInfo.TwoLetterISORegionName + System.Environment.NewLine;
			textBoxInfo.Text += System.Environment.NewLine;
            textBoxInfo.Text += "CultureInfo.DateTimeFormat.ShortTimePattern: " + cultureInfo.DateTimeFormat.ShortTimePattern + System.Environment.NewLine;
            textBoxInfo.Text += System.Environment.NewLine;
            ShowArray("DayNames", cultureInfo.DateTimeFormat.DayNames);
			ShowArray("MonthNames", cultureInfo.DateTimeFormat.MonthNames);
			textBoxInfo.Text += System.Environment.NewLine;
		}
		private void ShowArray(string title, string[] strings)
		{
			textBoxInfo.Text += title + System.Environment.NewLine;
			textBoxInfo.Text += "---------------" + System.Environment.NewLine;

			foreach (string s in strings)
			{
				textBoxInfo.Text += s + System.Environment.NewLine;
			}
			textBoxInfo.Text += System.Environment.NewLine;
		}

		private void buttonRegisterenGB_Click(object sender, EventArgs e)
		{
			CultureAndRegionInfoBuilder builder = new CultureAndRegionInfoBuilder("en-GB",
				CultureAndRegionModifiers.Replacement);

            builder.GregorianDateTimeFormat.ShortTimePattern = "HH:mm tt";

			builder.Register();
		}

		private void buttonShowenGB_Click(object sender, EventArgs e)
		{
			ShowCulture(new CultureInfo("en-GB"));
		}

		private void buttonUnregisterenGB_Click(object sender, EventArgs e)
		{
			CultureAndRegionInfoBuilder.Unregister("en-GB");
		}

		private void buttonRegisterenGBAcme_Click(object sender, EventArgs e)
		{
			CultureInfo cultureInfo = new CultureInfo("en-GB");
			RegionInfo regionInfo = new RegionInfo(cultureInfo.Name);

			CultureAndRegionInfoBuilder builder =
                new CultureAndRegionInfoBuilder("en-GB-Acme",
				CultureAndRegionModifiers.None);

			// load in the data from the existing culture and region
			builder.LoadDataFromCultureInfo(cultureInfo);
			builder.LoadDataFromRegionInfo(regionInfo);

			// make custom changes to the culture
            builder.GregorianDateTimeFormat.ShortTimePattern = "HH:mm tt";

			builder.Register();
		}

		private void buttonShowenGBAcme_Click(object sender, EventArgs e)
		{
			ShowCulture(new CultureInfo("en-GB-Acme"));
		}

		private void buttonUnregisterenGBAcme_Click(object sender, EventArgs e)
		{
			CultureAndRegionInfoBuilder.Unregister("en-GB-Acme");
		}

		private void buttonRegisteresESTradnlAcme_Click(object sender, EventArgs e)
		{
			// create the es-ES culture with the Traditional sort order
			CultureInfo cultureInfo = new CultureInfo(0x040A);
			RegionInfo regionInfo = new RegionInfo(cultureInfo.Name);

			CultureAndRegionInfoBuilder builder =
				new CultureAndRegionInfoBuilder("es-ES-Tradnl-Acme",
				CultureAndRegionModifiers.None);

			// load in the data from the existing culture and region
			builder.LoadDataFromCultureInfo(cultureInfo);
			builder.LoadDataFromRegionInfo(regionInfo);

			// make custom changes to the culture

			builder.Register();
		}

		private void buttonesESTradnl_Click(object sender, EventArgs e)
		{
			ShowCulture(new CultureInfo("es-ES-Tradnl-Acme"));
		}

		private void buttonUnregisteresESTradnl_Click(object sender, EventArgs e)
		{
			CultureAndRegionInfoBuilder.Unregister("es-ES-Tradnl-Acme");
		}

		private void buttonRegisterbnBD_Click(object sender, EventArgs e)
		{
			BengaliBangladeshCustomCulture.RegisterBengaliBangladeshCulture();
		}

		private void buttonShowbnBD_Click(object sender, EventArgs e)
		{
			ShowCulture(new CultureInfo("bn-BD"));
		}

		private void buttonUnregisterbdBD_Click(object sender, EventArgs e)
		{
			CultureAndRegionInfoBuilder.Unregister("bn-BD");
		}

		private void buttonRegisterpdPD_Click(object sender, EventArgs e)
		{
			PseudoTranslationCustomCulture.RegisterPseudoTranslationCulture();
		}

		private void buttonShowpdPD_Click(object sender, EventArgs e)
		{
			ShowCulture(new CultureInfo("pd-PD"));
		}

		private void buttonUnregisterpdPD_Click(object sender, EventArgs e)
		{
			CultureAndRegionInfoBuilder.Unregister("pd-PD");
		}

		private void buttonRegisteresUS_Click(object sender, EventArgs e)
		{
			CultureAndRegionInfoBuilder builder =
				CultureAndRegionInfoBuilderHelper.CreateCultureAndRegionInfoBuilder(
				new CultureInfo("es-ES"), new RegionInfo("en-US"));

            if (builder.RegionNativeName == "United States")
            {
                // the Spanish .NET Framework Language Pack was not installed
                // so update the region native name manually
                builder.RegionNativeName = "Estados Unidos";
                builder.CultureNativeName = "español (Estados Unidos)";
            }

			builder.Register();
		}

		private void buttonShowesUS_Click(object sender, EventArgs e)
		{
			ShowCulture(new CultureInfo("es-US"));
		}

		private void buttonUnregisteresUS_Click(object sender, EventArgs e)
		{
			CultureAndRegionInfoBuilder.Unregister("es-US");
		}

		private void buttonRegisterenUSSirius_Click(object sender, EventArgs e)
		{
			CultureAndRegionInfoBuilder builder =
				CultureAndRegionInfoBuilderHelper.CreateChildCultureAndRegionInfoBuilder(
				new CultureInfo("en-US"),
				"en-US-Sirius",
				"English (United States) (Sirius Publications)",
                "English (United States) (Sirius Publications)",
                "United States (Sirius Publications)",
                "United States (Sirius Publications)");

			builder.Register();
		}

		private void buttonShowenUSSirius_Click(object sender, EventArgs e)
		{
			ShowCulture(new CultureInfo("en-US-Sirius"));
		}

		private void buttonUnregisterenUSSirius_Click(object sender, EventArgs e)
		{
			CultureAndRegionInfoBuilder.Unregister("en-US-Sirius");
		}

        private void buttonExportcyGB_Click(object sender, EventArgs e)
        {
            CultureAndRegionInfoBuilderHelper.Export(new CultureInfo("cy-GB"), "cy-GB.xml", "en-GB", "en-GB", "en-GB");
            MessageBox.Show("cy-GB culture exported to cy-GB.xml");
        }

        private void buttonSaveenGB_Click(object sender, EventArgs e)
        {
            CultureAndRegionInfoBuilder builder = new CultureAndRegionInfoBuilder("en-GB",
                CultureAndRegionModifiers.Replacement);

            builder.GregorianDateTimeFormat.ShortTimePattern = "HH:mm tt";

            builder.Save("en-GB.ldml");
        }

        private void buttonSaveenGBAcme_Click(object sender, EventArgs e)
        {
            CultureInfo cultureInfo = new CultureInfo("en-GB");
            RegionInfo regionInfo = new RegionInfo(cultureInfo.Name);

            CultureAndRegionInfoBuilder builder =
                new CultureAndRegionInfoBuilder("en-GB-Acme",
                CultureAndRegionModifiers.None);

            // load in the data from the existing culture and region
            builder.LoadDataFromCultureInfo(cultureInfo);
            builder.LoadDataFromRegionInfo(regionInfo);

            // make custom changes to the culture
            builder.GregorianDateTimeFormat.ShortTimePattern = "HH:mm tt";

            builder.Save("en-GB-Acme.ldml");
        }

        private void buttonSaveesESTradnl_Click(object sender, EventArgs e)
        {
            // create the es-ES culture with the Traditional sort order
            CultureInfo cultureInfo = new CultureInfo(0x040A);
            RegionInfo regionInfo = new RegionInfo(cultureInfo.Name);

            CultureAndRegionInfoBuilder builder =
                new CultureAndRegionInfoBuilder("es-ES-Tradnl-Acme",
                CultureAndRegionModifiers.None);

            // load in the data from the existing culture and region
            builder.LoadDataFromCultureInfo(cultureInfo);
            builder.LoadDataFromRegionInfo(regionInfo);

            // make custom changes to the culture

            builder.Save("es-ES_Tradnl-Acme.ldml");
        }

        private void buttonSavebnBD_Click(object sender, EventArgs e)
        {
            CultureAndRegionInfoBuilder builder =
                BengaliBangladeshCustomCulture.CreateBengaliBangladeshCultureAndRegionInfoBuilder();

            builder.Save("bn-BD.ldml");
        }

        private void buttonSavepdPD_Click(object sender, EventArgs e)
        {
            CultureAndRegionInfoBuilder builder =
                PseudoTranslationCustomCulture.CreatePseudoTranslationCultureAndRegionInfoBuilder();

            builder.Save("pd-PD.ldml");
        }

        private void buttonSaveesUS_Click(object sender, EventArgs e)
        {
            CultureAndRegionInfoBuilder builder =
                CultureAndRegionInfoBuilderHelper.CreateCultureAndRegionInfoBuilder(
                new CultureInfo("es-ES"), new RegionInfo("en-US"));

            if (builder.RegionNativeName == "United States")
            {
                // the Spanish .NET Framework Language Pack was not installed
                // so update the region native name manually
                builder.RegionNativeName = "Estados Unidos";
                builder.CultureNativeName = "español (Estados Unidos)";
            }

            builder.Save("es-US.ldml");
        }

        private void buttonSaveenUSSirius_Click(object sender, EventArgs e)
        {
            CultureAndRegionInfoBuilder builder =
                CultureAndRegionInfoBuilderHelper.CreateChildCultureAndRegionInfoBuilder(
                new CultureInfo("en-US"),
                "en-US-Sirius",
                "English (United States) (Sirius Publications)",
                "English (United States) (Sirius Publications)",
                "United States (Sirius Publications)",
                "United States (Sirius Publications)");

            builder.Save("en-US.ldml");
        }

        private static CultureAndRegionInfoBuilder GetCLFCultureAndRegionInfoBuilder()
        {
            CultureInfo cultureInfo = new CultureInfo("es-CL");
            RegionInfo regionInfo = new RegionInfo("es-CL");

            CultureAndRegionInfoBuilder builder =
                CultureAndRegionInfoBuilderHelper.CreateChildCultureAndRegionInfoBuilder(
                new CultureInfo("es-CL"),
                "es-CL-CLF",
                cultureInfo.EnglishName + " (CLF)",
                cultureInfo.NativeName + " (CLF)",
                regionInfo.EnglishName + " (CLF)",
                regionInfo.NativeName + " (CLF)");

            builder.CurrencyEnglishName = "Chilean Unidad de Fomento";
            builder.CurrencyNativeName = "Chilean Unidad de Fomento";
            builder.ISOCurrencySymbol = "CLF";
            builder.NumberFormat.CurrencySymbol = "UF";
            return builder;
        }

        private void button1_Click(object sender, EventArgs e)
        {
            CultureAndRegionInfoBuilder builder = GetCLFCultureAndRegionInfoBuilder();
            builder.Register();
        }

        private void button2_Click(object sender, EventArgs e)
        {
            ShowCulture(new CultureInfo("es-CL-CLF"));
        }

        private void button3_Click(object sender, EventArgs e)
        {
            CultureAndRegionInfoBuilder.Unregister("es-CL-CLF");
        }

        private void button4_Click(object sender, EventArgs e)
        {
            CultureAndRegionInfoBuilder builder = GetCLFCultureAndRegionInfoBuilder();
            builder.Save("es-CL-CLF.ldml");
        }
	}
}