﻿// File           : Program.cs
// Original Author: Guy Smith-Ferrier
// Date Created   : September 2005
// Notes          : This file is part of the downloadable source code for .NET Internationalization, by
//                  Guy Smith-Ferrier, published by Addison-Wesley. See http://www.dotneti18n.com for details.
// Disclaimer     : No warranty is provided. Use at your own risk.
// Modification   : You are free to modify this code providing that this block of comments is not altered
//                  and is placed before any code.
using System;
using System.Collections.Generic;
using System.Text;
using System.Globalization;
using System.IO;

namespace RegisterCustomCulture
{
    /// <summary>
    /// Program holds the Main entry point
    /// </summary>
	class Program
	{
		static void Main(string[] args)
		{
			Console.WriteLine(ProgramResources.WelcomeText);
			Console.WriteLine("");
			if (args.GetLength(0) == 0)
				ShowSyntax();
			else if (AllFilesExist(args))
			{
				RegisterCustomCultures(args);
			}
		}
		private static void RegisterCustomCultures(string[] customCultureFiles)
		{
			foreach (string customCultureFile in customCultureFiles)
			{
                if (customCultureFile.StartsWith("/u:") || customCultureFile.StartsWith("/U:"))
                {
                    string customCultureName = customCultureFile.Substring(3);
                    CultureAndRegionInfoBuilder.Unregister(customCultureName);
                    Console.WriteLine(ProgramResources.CustomCultureUnregistered, customCultureName);
                }
                else
                {
                    CultureAndRegionInfoBuilder builder =
                        CultureAndRegionInfoBuilder.CreateFromLdml(customCultureFile);
                    builder.Register();
                    Console.WriteLine(ProgramResources.CustomCultureRegistered, customCultureFile);
                }
			}
			Console.WriteLine("");
			Console.WriteLine(ProgramResources.RegistrationComplete);
		}
		private static void ShowSyntax()
		{
			Console.WriteLine(ProgramResources.Syntax1);
			Console.WriteLine("");
            Console.WriteLine(ProgramResources.Syntax2);
			Console.WriteLine("");
            Console.WriteLine(ProgramResources.Syntax3);
			Console.WriteLine("");
            Console.WriteLine(ProgramResources.Syntax4);
			Console.WriteLine("");
            Console.WriteLine(ProgramResources.Syntax5);
			Console.WriteLine("");
            Console.WriteLine(ProgramResources.Syntax6);
            Console.WriteLine("");
            Console.WriteLine(ProgramResources.Syntax7);
            Console.WriteLine("");
            Console.WriteLine(ProgramResources.Syntax8);
            Console.WriteLine("");
		}
		private static bool AllFilesExist(string[] args)
		{
			foreach (string arg in args)
			{
                if (!(arg.StartsWith("/u:") || arg.StartsWith("/U:")))
                {
                    if (!File.Exists(arg))
                    {
                        Console.WriteLine(ProgramResources.CustomCultureFileDoesNotExist, arg);
                        return false;
                    }
                }
			}
			return true;
		}
	}
}
