// File           : BaseCodeGeneratorWithSite.cs
// Original Author: Guy Smith-Ferrier
// Date Created   : June 2008
// Notes          : This file is part of the downloadable source code for .NET Internationalization, by
//                  Guy Smith-Ferrier, published by Addison-Wesley. See http://www.dotneti18n.com for details.
// Disclaimer     : No warranty is provided. Use at your own risk.
// Modification   : You are free to modify this code providing that this block of comments is not altered
//                  and is placed before any code.
using Microsoft.VisualStudio.Designer.Interfaces;
using Microsoft.VisualStudio.OLE.Interop;
using Microsoft.VisualStudio.Shell;
using System;
using System.CodeDom.Compiler;
using System.ComponentModel;
using System.Runtime.InteropServices;

namespace Microsoft.VisualStudio.Design.Serialization
{
    public abstract class BaseCodeGeneratorWithSite : BaseCodeGenerator, IObjectWithSite
    {
        private static Guid CodeDomInterfaceGuid = new Guid("{73E59688-C7C4-4a85-AF64-A538754784C5}");
        private CodeDomProvider codeDomProvider;
        private static Guid CodeDomServiceGuid = CodeDomInterfaceGuid;
        private ServiceProvider serviceProvider;
        private object site;

        protected BaseCodeGeneratorWithSite()
        {
        }

        public override int DefaultExtension(out string ext)
        {
            string fileExtension = this.CodeProvider.FileExtension;
            if (((fileExtension != null) && (fileExtension.Length > 0)) && (fileExtension[0] != '.'))
            {
                fileExtension = "." + fileExtension;
            }
            ext = fileExtension;
            return 0;
        }

        protected virtual ICodeGenerator GetCodeWriter()
        {
            CodeDomProvider codeProvider = this.CodeProvider;
            if (codeProvider != null)
            {
                return codeProvider.CreateGenerator();
            }
            return null;
        }

        protected object GetService(Guid serviceGuid)
        {
            return this.SiteServiceProvider.GetService(serviceGuid);
        }

        protected object GetService(Type serviceType)
        {
            return this.SiteServiceProvider.GetService(serviceType);
        }

        public virtual void GetSite(ref Guid riid, out IntPtr ppvSite)
        {
            if (this.site == null)
            {
                throw new Win32Exception(-2147467259);
            }
            IntPtr iUnknownForObject = Marshal.GetIUnknownForObject(this.site);
            try
            {
                Marshal.QueryInterface(iUnknownForObject, ref riid, out ppvSite);
                if (ppvSite == IntPtr.Zero)
                {
                    throw new Win32Exception(-2147467262);
                }
            }
            finally
            {
                if (iUnknownForObject != IntPtr.Zero)
                {
                    Marshal.Release(iUnknownForObject);
                    iUnknownForObject = IntPtr.Zero;
                }
            }
        }

        public virtual void SetSite(object pUnkSite)
        {
            this.site = pUnkSite;
            this.codeDomProvider = null;
            this.serviceProvider = null;
        }

        protected virtual CodeDomProvider CodeProvider
        {
            get
            {
                if (this.codeDomProvider == null)
                {
                    IVSMDCodeDomProvider service = (IVSMDCodeDomProvider) this.GetService(CodeDomServiceGuid);
                    if (service != null)
                    {
                        this.codeDomProvider = (CodeDomProvider) service.CodeDomProvider;
                    }
                }
                return this.codeDomProvider;
            }
            set
            {
                if (value == null)
                {
                    throw new ArgumentNullException();
                }
                this.codeDomProvider = value;
            }
        }

        private ServiceProvider SiteServiceProvider
        {
            get
            {
                if (this.serviceProvider == null)
                {
                    Microsoft.VisualStudio.OLE.Interop.IServiceProvider site = this.site as Microsoft.VisualStudio.OLE.Interop.IServiceProvider;
                    this.serviceProvider = new ServiceProvider(site);
                }
                return this.serviceProvider;
            }
        }
    }
}

