﻿// File           : BaseCodeGeneratorWithSiteWithoutCodeDom.cs
// Original Author: Guy Smith-Ferrier
// Date Created   : February 2012
// Notes          : This file is part of the downloadable source code for .NET Internationalization, by
//                  Guy Smith-Ferrier, published by Addison-Wesley. See http://www.dotneti18n.com for details.
// Disclaimer     : No warranty is provided. Use at your own risk.
// Modification   : You are free to modify this code providing that this block of comments is not altered
//                  and is placed before any code.
using System;
using System.ComponentModel;
using System.Runtime.InteropServices;
using Microsoft.VisualStudio.Design.Serialization;
using Microsoft.VisualStudio.OLE.Interop;
using Microsoft.VisualStudio.Shell;

namespace Internationalization.VisualStudio.Design.Serialization
{
    public abstract class BaseCodeGeneratorWithSiteWithoutCodeDom : BaseCodeGenerator, IObjectWithSite
    {
        private object site;
        private ServiceProvider serviceProvider;

        protected BaseCodeGeneratorWithSiteWithoutCodeDom()
        {
        }

        protected object GetService(Guid serviceGuid)
        {
            return this.SiteServiceProvider.GetService(serviceGuid);
        }

        protected object GetService(Type serviceType)
        {
            return this.SiteServiceProvider.GetService(serviceType);
        }

        public virtual void GetSite(ref Guid riid, out IntPtr ppvSite)
        {
            if (this.site == null)
            {
                throw new Win32Exception(-2147467259);
            }
            IntPtr iUnknownForObject = Marshal.GetIUnknownForObject(this.site);
            try
            {
                Marshal.QueryInterface(iUnknownForObject, ref riid, out ppvSite);
                if (ppvSite == IntPtr.Zero)
                {
                    throw new Win32Exception(-2147467262);
                }
            }
            finally
            {
                if (iUnknownForObject != IntPtr.Zero)
                {
                    Marshal.Release(iUnknownForObject);
                    iUnknownForObject = IntPtr.Zero;
                }
            }
        }

        public virtual void SetSite(object pUnkSite)
        {
            this.site = pUnkSite;
        }

        private ServiceProvider SiteServiceProvider
        {
            get
            {
                if (this.serviceProvider == null)
                {
                    Microsoft.VisualStudio.OLE.Interop.IServiceProvider site = this.site as Microsoft.VisualStudio.OLE.Interop.IServiceProvider;
                    this.serviceProvider = new ServiceProvider(site);
                }
                return this.serviceProvider;
            }
        }
    }
}
