// File           : BaseResourceCodeGeneratorWithSite.cs
// Original Author: Guy Smith-Ferrier
// Date Created   : June 2008
// Notes          : This file is part of the downloadable source code for .NET Internationalization, by
//                  Guy Smith-Ferrier, published by Addison-Wesley. See http://www.dotneti18n.com for details.
// Disclaimer     : No warranty is provided. Use at your own risk.
// Modification   : You are free to modify this code providing that this block of comments is not altered
//                  and is placed before any code.
using Microsoft.VisualStudio;
using Microsoft.VisualStudio.Design;
using Microsoft.VisualStudio.OLE.Interop;
using Microsoft.VisualStudio.Shell;
using Microsoft.VisualStudio.Shell.Interop;
using System;
using System.CodeDom;
using System.Collections;
using System.Drawing;
using System.Globalization;
using System.IO;
using System.Resources;
using System.Resources.Tools;
using System.Runtime.InteropServices;
using System.Text;
using Microsoft.VisualStudio.Design.Serialization;

namespace Internationalization.VisualStudio.Design.Serialization
{
    public abstract class BaseResourceCodeGeneratorWithSite : BaseCodeGeneratorWithSite, IVsRefactorNotify
    {
        private const string DesignerExtension = ".Designer";
        private IVsRefactorNotify refactorNotifyImplementer;
        private static Guid ResourceEditorRefactorNotifyService = new Guid("E7CEE0FD-FAE7-46b4-BD50-9D044BAC5A7C");

        public override int DefaultExtension(out string ext)
        {
            string str;
            ext = string.Empty;
            int hr = base.DefaultExtension(out str);
            if (!NativeMethods.Succeeded(hr))
            {
                return hr;
            }
            if (!string.IsNullOrEmpty(str))
            {
                ext = ".Designer" + str;
            }
            return 0;
        }
        protected virtual CodeCompileUnit GenerateCodeCompileUnit(
            IDictionary resourceList, string fileNameWithoutExtension, string fileNameSpace, 
            string resourcesNamespace, System.CodeDom.Compiler.CodeDomProvider codeProvider, bool internalClass,
            out string[] strArray)
        {
            if (resourcesNamespace != null)
            {
                return StronglyTypedResourceBuilder.Create(resourceList, fileNameWithoutExtension, fileNameSpace, resourcesNamespace, codeProvider, internalClass, out strArray);
            }
            else
            {
                return StronglyTypedResourceBuilder.Create(resourceList, fileNameWithoutExtension, fileNameSpace, codeProvider, internalClass, out strArray);
            }
        }

        protected override byte[] GenerateCode(string inputFileName, string inputFileContent)
        {
            string[] strArray;
            if (string.IsNullOrEmpty(inputFileContent) || IsLocalizedFile(inputFileName))
            {
                if (base.CodeGeneratorProgress != null)
                {
                    NativeMethods.ThrowOnFailure(base.CodeGeneratorProgress.Progress(100, 100));
                }
                return null;
            }
            StreamWriter w = new StreamWriter(new MemoryStream(), Encoding.UTF8);
            IDictionary resourceList = new Hashtable(StringComparer.OrdinalIgnoreCase);
            IDictionary dictionary2 = new Hashtable(StringComparer.OrdinalIgnoreCase);
            using (IResourceReader reader = ResXResourceReader.FromFileContents(inputFileContent))
            {
                ResXResourceReader reader2 = reader as ResXResourceReader;
                if (reader2 != null)
                {
                    reader2.UseResXDataNodes = true;
                    string directoryName = Path.GetDirectoryName(inputFileName);
                    reader2.BasePath = Path.GetFullPath(directoryName);
                }
                foreach (DictionaryEntry entry in reader)
                {
                    ResXDataNode node = (ResXDataNode)entry.Value;
                    resourceList.Add(entry.Key, node);
                    dictionary2.Add(entry.Key, node.GetNodePosition());
                }
            }
            string resourcesNamespace = this.GetResourcesNamespace();
            string fileNameWithoutExtension = Path.GetFileNameWithoutExtension(inputFileName);
            bool internalClass = this.MakeClassInternal();

            CodeCompileUnit unit = GenerateCodeCompileUnit(resourceList, fileNameWithoutExtension, base.FileNameSpace,
                resourcesNamespace, this.CodeProvider, internalClass, out strArray);

            if (base.CodeGeneratorProgress != null)
            {
                foreach (string str4 in strArray)
                {
                    Point point = (Point)dictionary2[str4];
                    base.CodeGeneratorProgress.GeneratorError(1, 1, SR.GetString("CannotCreatePropertyForResource", new object[] { str4 }), (uint)point.Y, (uint)point.X);
                }
                base.CodeGeneratorProgress.Progress(70, 100);
            }
            this.HandleCodeCompileUnit(unit);
            if (base.CodeGeneratorProgress != null)
            {
                base.CodeGeneratorProgress.Progress(0x4b, 100);
            }
            this.CodeProvider.CreateGenerator().GenerateCodeFromCompileUnit(unit, w, null);
            if (base.CodeGeneratorProgress != null)
            {
                NativeMethods.ThrowOnFailure(base.CodeGeneratorProgress.Progress(100, 100));
            }
            // TODO: Implement UpdateGlobalObject method
            // this.UpdateGlobalObject(inputFileName);
            w.Flush();
            return base.StreamToBytes(w.BaseStream);
        }

        protected string GetResourcesNamespace()
        {
            string str = null;
            try
            {
                IntPtr ptr;
                Guid gUID = typeof(IVsBrowseObject).GUID;
                this.GetSite(ref gUID, out ptr);
                if (ptr != IntPtr.Zero)
                {
                    IVsHierarchy hierarchy;
                    uint num;
                    object obj3;
                    IVsBrowseObject objectForIUnknown = Marshal.GetObjectForIUnknown(ptr) as IVsBrowseObject;
                    Marshal.Release(ptr);
                    if (objectForIUnknown == null)
                    {
                        return str;
                    }
                    objectForIUnknown.GetProjectItem(out hierarchy, out num);
                    if (hierarchy == null)
                    {
                        return str;
                    }
                    hierarchy.GetProperty(num, -2049, out obj3);
                    string str2 = obj3 as string;
                    if (str2 == null)
                    {
                        return str;
                    }
                    str = str2;
                }
            }
            catch (Exception exception)
            {
                if (ProjectUtilities.IsCriticalException(exception))
                {
                    throw;
                }
            }
            return str;
        }

        protected virtual void HandleCodeCompileUnit(CodeCompileUnit ccu)
        {
        }

        private static bool IsLocalizedFile(string fileName)
        {
            if (!string.IsNullOrEmpty(fileName) && fileName.EndsWith(".resx", StringComparison.OrdinalIgnoreCase))
            {
                string str = fileName.Substring(0, fileName.Length - 5);
                if (!string.IsNullOrEmpty(str))
                {
                    int num = str.LastIndexOf('.');
                    if (num > 0)
                    {
                        string str2 = str.Substring(num + 1);
                        if (!string.IsNullOrEmpty(str2))
                        {
                            try
                            {
                                if (new CultureInfo(str2) != null)
                                {
                                    return true;
                                }
                            }
                            catch (ArgumentException)
                            {
                            }
                        }
                    }
                }
            }
            return false;
        }

        protected virtual bool MakeClassInternal()
        {
            string str = (this.CodeProvider != null) ? this.CodeProvider.FileExtension : null;
            if (!string.IsNullOrEmpty(str) && str.EndsWith("jsl", StringComparison.OrdinalIgnoreCase))
            {
                return false;
            }
            return true;
        }

        int IVsRefactorNotify.OnAddParams(IVsHierarchy phier, uint itemId, string lpszRQName, uint cParams, uint[] rgszParamIndexes, string[] rgszRQTypeNames, string[] rgszParamNames)
        {
            if (this.RefactorNotifyImplementer != null)
            {
                return this.RefactorNotifyImplementer.OnAddParams(phier, itemId, lpszRQName, cParams, rgszParamIndexes, rgszRQTypeNames, rgszParamNames);
            }
            return -2147418113;
        }

        int IVsRefactorNotify.OnBeforeAddParams(IVsHierarchy phier, uint itemId, string lpszRQName, uint cParams, uint[] rgszParamIndexes, string[] rgszRQTypeNames, string[] rgszParamNames, out Array prgAdditionalCheckoutVSITEMIDS)
        {
            if (this.RefactorNotifyImplementer != null)
            {
                return this.RefactorNotifyImplementer.OnBeforeAddParams(phier, itemId, lpszRQName, cParams, rgszParamIndexes, rgszRQTypeNames, rgszParamNames, out prgAdditionalCheckoutVSITEMIDS);
            }
            prgAdditionalCheckoutVSITEMIDS = null;
            return -2147418113;
        }

        int IVsRefactorNotify.OnBeforeGlobalSymbolRenamed(IVsHierarchy phier, uint itemId, uint cRQNames, string[] rglpszRQName, string lpszNewName, out Array prgAdditionalCheckoutVSITEMIDS)
        {
            if (this.RefactorNotifyImplementer != null)
            {
                return this.RefactorNotifyImplementer.OnBeforeGlobalSymbolRenamed(phier, itemId, cRQNames, rglpszRQName, lpszNewName, out prgAdditionalCheckoutVSITEMIDS);
            }
            prgAdditionalCheckoutVSITEMIDS = null;
            return -2147418113;
        }

        int IVsRefactorNotify.OnBeforeRemoveParams(IVsHierarchy phier, uint itemId, string lpszRQName, uint cParamIndexes, uint[] rgParamIndexes, out Array prgAdditionalCheckoutVSITEMIDS)
        {
            if (this.RefactorNotifyImplementer != null)
            {
                return this.RefactorNotifyImplementer.OnBeforeRemoveParams(phier, itemId, lpszRQName, cParamIndexes, rgParamIndexes, out prgAdditionalCheckoutVSITEMIDS);
            }
            prgAdditionalCheckoutVSITEMIDS = null;
            return -2147418113;
        }

        int IVsRefactorNotify.OnBeforeReorderParams(IVsHierarchy phier, uint itemId, string lpszRQName, uint cParamIndexes, uint[] rgParamIndexes, out Array prgAdditionalCheckoutVSITEMIDS)
        {
            if (this.RefactorNotifyImplementer != null)
            {
                return this.RefactorNotifyImplementer.OnBeforeReorderParams(phier, itemId, lpszRQName, cParamIndexes, rgParamIndexes, out prgAdditionalCheckoutVSITEMIDS);
            }
            prgAdditionalCheckoutVSITEMIDS = null;
            return -2147418113;
        }

        int IVsRefactorNotify.OnGlobalSymbolRenamed(IVsHierarchy phier, uint itemId, uint cRQNames, string[] rglpszRQName, string lpszNewName)
        {
            if (this.RefactorNotifyImplementer != null)
            {
                return this.RefactorNotifyImplementer.OnGlobalSymbolRenamed(phier, itemId, cRQNames, rglpszRQName, lpszNewName);
            }
            return -2147418113;
        }

        int IVsRefactorNotify.OnRemoveParams(IVsHierarchy phier, uint itemId, string lpszRQName, uint cParamIndexes, uint[] rgParamIndexes)
        {
            if (this.RefactorNotifyImplementer != null)
            {
                return this.RefactorNotifyImplementer.OnRemoveParams(phier, itemId, lpszRQName, cParamIndexes, rgParamIndexes);
            }
            return -2147418113;
        }

        int IVsRefactorNotify.OnReorderParams(IVsHierarchy phier, uint itemId, string lpszRQName, uint cParamIndexes, uint[] rgParamIndexes)
        {
            if (this.RefactorNotifyImplementer != null)
            {
                return this.RefactorNotifyImplementer.OnReorderParams(phier, itemId, lpszRQName, cParamIndexes, rgParamIndexes);
            }
            return -2147418113;
        }

        private IVsRefactorNotify RefactorNotifyImplementer
        {
            get
            {
                if (this.refactorNotifyImplementer == null)
                {
                    Microsoft.VisualStudio.OLE.Interop.IServiceProvider globalService = Package.GetGlobalService(typeof(Microsoft.VisualStudio.OLE.Interop.IServiceProvider)) as Microsoft.VisualStudio.OLE.Interop.IServiceProvider;
                    if (globalService != null)
                    {
                        ServiceProvider provider2 = new ServiceProvider(globalService);
                        this.refactorNotifyImplementer = provider2.GetService(ResourceEditorRefactorNotifyService) as IVsRefactorNotify;
                    }
                }
                return this.refactorNotifyImplementer;
            }
        }
    }
    public class SR
    {
        public static string GetString(string key, params object[] args)
        {
            return key;
        }
    }
}