﻿// File           : JavaScriptAddParentsResourceCodeGenerator.cs
// Original Author: Guy Smith-Ferrier
// Date Created   : February 2012
// Notes          : This file is part of the downloadable source code for .NET Internationalization, by
//                  Guy Smith-Ferrier, published by Addison-Wesley. See http://www.dotneti18n.com for details.
// Disclaimer     : No warranty is provided. Use at your own risk.
// Modification   : You are free to modify this code providing that this block of comments is not altered
//                  and is placed before any code.
using System.Runtime.InteropServices;
using System;
using System.Collections.Generic;
using System.Text;
using System.Collections;
using System.Resources;
using System.Globalization;
using System.IO;

namespace Internationalization.VisualStudio.Design.Serialization
{
    [Guid("89757212-CADC-4170-A0AE-05AF7178601B")]
    public class JavaScriptAddParentsResourceCodeGenerator: JavaScriptResourceCodeGenerator
    {
        protected bool IncludeInvariantWithParents { get; set; }

        public JavaScriptAddParentsResourceCodeGenerator()
        {
            this.IncludeInvariantWithParents = false;
        }

        protected override Hashtable GetResources(string resxFilename)
        {
            // get the resources for this .resx file
            ResXResourceReader resourceReader = new ResXResourceReader(resxFilename);
            Hashtable resources = new Hashtable();
            AddResources(resourceReader, resources);
            AddParentResources(resxFilename, resources);
            return resources;
        }

        protected virtual void AddParentResources(string resxFilename, Hashtable resources)
        {
            // add the resources from the parent .resx files
            CultureInfo cultureInfo = GetCultureFromFilename(resxFilename);
            if (cultureInfo != null)
            {
                // this is a culture-neutral or culture-specific file
                CultureInfo parentCultureInfo = cultureInfo.Parent;
                if (parentCultureInfo.Equals(CultureInfo.InvariantCulture))
                {
                    // the parent is the invariant culture
                    if (this.IncludeInvariantWithParents)
                    {
                        string parentResxFilename = Path.GetFileNameWithoutExtension(Path.GetFileNameWithoutExtension(resxFilename)) + Path.GetExtension(resxFilename);

                        parentResxFilename = Path.Combine(Path.GetDirectoryName(resxFilename), parentResxFilename);

                        ResXResourceReader resourceReader = new ResXResourceReader(parentResxFilename);
                        AddResources(resourceReader, resources);
                    }
                }
                else
                {
                    // the culture's parent is not the invariant culture
                    string parentResxFilename = 
                        Path.GetFileNameWithoutExtension(Path.GetFileNameWithoutExtension(resxFilename)) + "." + parentCultureInfo.Name + Path.GetExtension(resxFilename);

                    parentResxFilename = Path.Combine(Path.GetDirectoryName(resxFilename), parentResxFilename);

                    if (File.Exists(parentResxFilename))
                    {
                        ResXResourceReader resourceReader = new ResXResourceReader(parentResxFilename);
                        AddResources(resourceReader, resources);
                    }

                    AddParentResources(parentResxFilename, resources);
                }
            }
        }
    }
}
