using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Configuration.Install;
using System.Security.Permissions;
using System.Runtime.InteropServices;
using Microsoft.Win32;
using System.Text;
using System.Reflection;
using Internationalization.VisualStudio.Design.Serialization;
using System.Diagnostics;

namespace Internationalization.Resources
{
    [RunInstaller(true)]
    public partial class ResourceCodeGeneratorsInstaller : Installer
    {
        public ResourceCodeGeneratorsInstaller()
        {
            InitializeComponent();
        }

        [SecurityPermission(SecurityAction.Demand)]
        public override void Install(System.Collections.IDictionary stateSaver)
        {
            base.Install(stateSaver);

            ComRegisterFunction(null);
        }

        [SecurityPermission(SecurityAction.Demand)]
        public override void Uninstall(System.Collections.IDictionary savedState)
        {
            base.Uninstall(savedState);

            ComUnregisterFunction(null);
        }

        private const string visualStudioRegistryKey = @"SOFTWARE\Microsoft\VisualStudio\";

        private static VisualStudioVersion[] visualStudioVersions;
        private static string[] languageGuids;

        private static Type[] resourceCodeGeneratorTypes;

        private static string[] resourceCodeGeneratorDescriptions;

        static ResourceCodeGeneratorsInstaller()
        {
            visualStudioVersions = new VisualStudioVersion[]
            {
                new VisualStudioVersion() { VersionKey = "8.0", RootRegistryKey = Registry.LocalMachine },
                new VisualStudioVersion() { VersionKey = "9.0", RootRegistryKey = Registry.LocalMachine },
                new VisualStudioVersion() { VersionKey = "10.0", RootRegistryKey = Registry.LocalMachine },
                new VisualStudioVersion() { VersionKey = "11.0_Config", RootRegistryKey = Registry.CurrentUser }
            };

            languageGuids = new string[] {
            "{FAE04EC1-301F-11D3-BF4B-00C04F79EFBC}",
            "{164B10B9-B200-11D0-8C61-00A0C91E29D5}",
            "{E6FDF8B0-F3D1-11D4-8576-0002A516ECE8}"
            };

            resourceCodeGeneratorTypes = new Type[] {
                typeof(ResourceCodeGenerator),
                typeof(PublicResourceCodeGenerator),
                typeof(ResourceProviderCodeGenerator),
                typeof(PublicResourceProviderCodeGenerator),
                typeof(GlobalResourceProviderProxyGenerator),
                typeof(JavaScriptResourceCodeGenerator),
                typeof(JavaScriptAddParentsResourceCodeGenerator),
                typeof(JavaScriptAddAllParentsResourceCodeGenerator)
            };

            resourceCodeGeneratorDescriptions = new string[] {
                "Resource Code Generator",
                "Public Resource Code Generator",
                "Resource Provider Code Generator",
                "Public Resource Provider Code Generator",
                "Global Resource Provider Proxy Generator",
                "JavaScript Resource Code Generator",
                "JavaScript (Add Parents) Resource Code Generator",
                "JavaScript (Add All Parents) Resource Code Generator"
            };
        }
        
        [ComRegisterFunction]
        public static void ComRegisterFunction(Type type)
        {
            foreach (VisualStudioVersion visualStudioVersion in visualStudioVersions)
            {
                for (int resourceCodeGeneratorNumber = 0;
                    resourceCodeGeneratorNumber < resourceCodeGeneratorTypes.GetLength(0); resourceCodeGeneratorNumber++)
                {
                    Type resourceCodeGeneratorType = resourceCodeGeneratorTypes[resourceCodeGeneratorNumber];
                    string resourceCodeGeneratorDescription = resourceCodeGeneratorDescriptions[resourceCodeGeneratorNumber];

                    using (RegistryKey vsNetRegistryKey = visualStudioVersion.RootRegistryKey.OpenSubKey(
                        visualStudioRegistryKey + visualStudioVersion.VersionKey,
                        RegistryKeyPermissionCheck.ReadWriteSubTree))
                    {
                        if (vsNetRegistryKey != null)
                        {
                            foreach (string languageGuid in languageGuids)
                            {
                                string generatorRegistryKeyPath = string.Format(@"Generators\{0}\{1}",
                                    languageGuid, resourceCodeGeneratorType.Name);

                                using (RegistryKey generatorRegistryKey = vsNetRegistryKey.CreateSubKey(generatorRegistryKeyPath,
                                    RegistryKeyPermissionCheck.ReadWriteSubTree))
                                {
                                    generatorRegistryKey.SetValue("", resourceCodeGeneratorDescription);
                                    generatorRegistryKey.SetValue("CLSID", resourceCodeGeneratorType.GUID.ToString("B"));
                                    generatorRegistryKey.SetValue("GeneratesDesignTimeSource", 1);
                                }
                            }
                        }
                    }
                }
            }
        }

        [ComUnregisterFunction]
        public static void ComUnregisterFunction(Type type)
        {
            foreach (VisualStudioVersion visualStudioVersion in visualStudioVersions)
            {
                foreach (Type resourceCodeGeneratorType in resourceCodeGeneratorTypes)
                {
                    foreach (string languageGuid in languageGuids)
                    {
                        string generatorRegistryKeyPath = string.Format(@"{0}{1}\Generators\{2}\{3}",
                            visualStudioRegistryKey, visualStudioVersion.VersionKey,
                            languageGuid, resourceCodeGeneratorType.Name);

                        visualStudioVersion.RootRegistryKey.DeleteSubKey(generatorRegistryKeyPath, false);
                    }
                }
            }
        }
    }
}