﻿using System;
using System.Collections.Generic;
using System.Text;
using System.Web.Compilation;
using System.Resources;
using System.Reflection;

namespace Internationalization.Resources.Web
{
    public class GenericResourceProviderFactory: ResourceProviderFactory
    {
        public GenericResourceProviderFactory()
        {
        }
        public override IResourceProvider CreateGlobalResourceProvider(string classKey)
        {
            return new GlobalResourceProvider(classKey);
        }
        public override IResourceProvider CreateLocalResourceProvider(string virtualPath)
        {
            return new GlobalResourceProvider(virtualPath);
        }
    }
    public class GlobalResourceProvider : IResourceProvider
    {
        private string classKey;
        private ResourceManager resourceManager;

        public GlobalResourceProvider(string classKey)
        {
            this.classKey = classKey;
        }
        protected ResourceManager ResourceManager
        {
            get
            {
                if (resourceManager == null)
                {
                    Assembly appResourcesAssembly = GetAppResourcesAssembly();
                    if (appResourcesAssembly == null)
                    {
                        return null;
                    }
                    resourceManager = new ResourceManager("Resources." + classKey, appResourcesAssembly);
                    resourceManager.IgnoreCase = true;
                }
                return resourceManager;
            }
        }
        protected virtual Assembly GetAppResourcesAssembly()
        {
            PropertyInfo propertyInfo = typeof(BuildManager).GetProperty("AppResourcesAssembly", System.Reflection.BindingFlags.Static | System.Reflection.BindingFlags.NonPublic);
            if (propertyInfo == null)
                return null;
            else
            {
                Assembly assembly = (Assembly)propertyInfo.GetValue(null, new object[] { });
                if (assembly == null)
                    return null;
                else
                    return assembly;
            }
        }
        public object GetObject(string resourceKey, System.Globalization.CultureInfo culture)
        {
            object obj = ResourceManager.GetObject(resourceKey, culture);
            if (obj is String)
                return "(" + resourceKey + "): " + (String)obj;
            else
                return obj;
        }

        public System.Resources.IResourceReader ResourceReader
        {
            get
            {
                // return new ResXResourceReader
                throw new InvalidOperationException();
            }
        }
    }
}
