// File           : EnvironmentEx.cs
// Original Author: Guy Smith-Ferrier
// Date Created   : September 2005
// Notes          : This file is part of the downloadable source code for .NET Internationalization, by
//                  Guy Smith-Ferrier, published by Addison-Wesley. See http://www.dotneti18n.com for details.
// Disclaimer     : No warranty is provided. Use at your own risk.
// Modification   : You are free to modify this code providing that this block of comments is not altered
//                  and is placed before any code.
using System;
using System.Collections.Generic;
using System.Text;
using System.Resources;
using System.Reflection;

namespace Globalization
{
    /// <summary>
    /// EnvironmentEx provides environment-wide methods
    /// </summary>
    public class EnvironmentEx
    {
        private static ResourceManager resourceManager;
        static EnvironmentEx()
        {
            resourceManager = new ResourceManager(
                "Globalization.EnvironmentExResources", Assembly.GetExecutingAssembly());
        }
        /// <summary>
        /// GetResourceString gets a named resource string from a common resource pool
        /// </summary>
        /// <param name="resourceStringName">The resource key name</param>
        /// <param name="args">Arguments to replace placeholders with</param>
        /// <returns>A string from the common resource pool</returns>
        public static string GetResourceString(string resourceStringName, object[] args)
        {
            string resourceString = resourceManager.GetString(resourceStringName);
            if (resourceString == null || args.GetLength(0) == 0)
                return resourceString;
            return String.Format(resourceString, args);
        }
    }
}
