// File           : EmptyResourceReader.cs
// Original Author: Guy Smith-Ferrier
// Date Created   : September 2005
// Notes          : This file is part of the downloadable source code for .NET Internationalization, by
//                  Guy Smith-Ferrier, published by Addison-Wesley. See http://www.dotneti18n.com for details.
// Disclaimer     : No warranty is provided. Use at your own risk.
// Modification   : You are free to modify this code providing that this block of comments is not altered
//                  and is placed before any code.
using System;
using System.Collections;
using System.Resources;

namespace Internationalization.Common
{
	/// <summary>
	/// EmptyResourceReader is a resource reader which does not read from a source
	/// </summary>
	/// <remarks>At first this might seem like a pointless idea but it allows you to create new ResourceSets
	/// which do not read from a source.</remarks>
	/// <example>
	/// ResourceSet resourceSet = new ResourceSet(new EmptyResourceReader());
	/// </example>
	public class EmptyResourceReader: IResourceReader
	{
        /// <summary>
        /// GetEnumerator returns an enumerator to enumerate through the resources
        /// </summary>
        /// <returns>An IDictionaryEnumerator</returns>
		public IDictionaryEnumerator GetEnumerator()
		{
			return new Hashtable().GetEnumerator();
		}
        /// <summary>
        /// Close closes the resource reader
        /// </summary>
		public void Close()
		{
		}
		IEnumerator System.Collections.IEnumerable.GetEnumerator()
		{
			return this.GetEnumerator();
		}
        /// <summary>
        /// Releases all resources used by the resource reader
        /// </summary>
		public void Dispose()
		{
		}
	}
}
