// File           : OnlineTranslator.cs
// Original Author: Guy Smith-Ferrier
// Date Created   : September 2005
// Notes          : This file is part of the downloadable source code for .NET Internationalization, by
//                  Guy Smith-Ferrier, published by Addison-Wesley. See http://www.dotneti18n.com for details.
// Disclaimer     : No warranty is provided. Use at your own risk.
// Modification   : You are free to modify this code providing that this block of comments is not altered
//                  and is placed before any code.
using System;
using System.Globalization;

namespace Internationalization.Translation
{
	/// <summary>
	/// OnlineTranslator is an HTML translator for www.online-translator.com
	/// </summary>
	public class OnlineTranslator: HtmlTranslator
	{
        /// <summary>
        /// Constructs an OnlineTranslator object
        /// </summary>
		public OnlineTranslator():
            base(OnlineTranslatorResources.Name, @"http://www.online-translator.com/text.asp", new string[,]
			{
				{"en", "ru"},
				{"ru", "en"},
				{"de", "ru"},
				{"ru", "de"},
				{"fr", "ru"},
				{"ru", "fr"},
				{"es", "ru"},
				{"ru", "es"},
				{"it", "ru"},
				{"en", "de"},
				{"de", "en"},
				{"en", "es"},
				{"es", "en"},
				{"en", "fr"},
				{"fr", "en"},
				{"en", "pt"}
			})
		{
		}
        /// <summary>
        /// GetPostData gets the website-specific post data for sending to the URL
        /// </summary>
        /// <param name="inputLanguage">The language of the input text</param>
        /// <param name="outputLanguage">The language of the output text</param>
        /// <param name="text">The text to be translated</param>
        /// <returns>The post data to send to the URL</returns>
        public override string GetPostData(string inputLanguage, string outputLanguage, string text)
		{
			string inputLanguageName  = new CultureInfo(inputLanguage ).EnglishName;
			string outputLanguageName = new CultureInfo(outputLanguage).EnglishName;
			string languagePair = inputLanguageName.Substring(0, 1) + outputLanguageName.Substring(0, 1);
			return @"lang=en&status=translate&source=" + Encode(text) + "&SResalt=" + Encode(text) + 
				"&direction=" + languagePair.ToLower() + "&template=General&image1.x=61&image1.y=11";
		}
        /// <summary>
        /// GetTranslation extracts the translated text from the inner text returned from the website
        /// </summary>
        /// <param name="inputLanguage">The language of the input text</param>
        /// <param name="outputLanguage">The language of the output text</param>
        /// <param name="innerText">The inner text returned from the website</param>
        /// <returns>The translated text</returns>
        /// <remarks>This is the most fragile part of an HtmlTranslator's implementation.
        /// If this translator fails check this method first. The most likely reason for
        /// failure is that the resulting HTML (and therefore inner text) has changed.</remarks>
        protected override string GetTranslation(string inputLanguage, string outputLanguage, string innerText)
		{
			string startText = "Transliterate unknown words:";
			int index = innerText.IndexOf(startText);
			if (index == -1)
				return String.Empty;

			innerText = innerText.Substring(index + startText.Length + 2).TrimStart(new char[] {' ', (char) 10, (char) 13});
            if (innerText.StartsWith("Spell-checking is performed by ORFO."))
                innerText = innerText.Substring(37).TrimStart(new char[] {' ', (char) 10, (char) 13});
			if (innerText.StartsWith("Download PROMT translation software"))
				// strip out the advert first
				innerText = innerText.Substring(36).TrimStart(new char[] {' ', (char) 10, (char) 13});

            index = innerText.IndexOf("Choose Translator:");
            if (index == -1)
            {
                index = innerText.IndexOf("How to translate");
                if (index == -1 || index == 0)
                    return String.Empty;
            }
            else if (index == 0)
                return String.Empty;

			return innerText.Substring(0, index - 1).TrimEnd(new char[] {' ', (char) 10, (char) 13});
		}
	}
}
