// File           : ApniUrduTranslator.cs
// Original Author: Guy Smith-Ferrier
// Date Created   : September 2005
// Notes          : This file is part of the downloadable source code for .NET Internationalization, by
//                  Guy Smith-Ferrier, published by Addison-Wesley. See http://www.dotneti18n.com for details.
// Disclaimer     : No warranty is provided. Use at your own risk.
// Modification   : You are free to modify this code providing that this block of comments is not altered
//                  and is placed before any code.
using System;
using System.Text;

namespace Internationalization.Translation
{
	/// <summary>
	/// ApniUrduTranslator is a translator for the Apni English to Urdu translator
	/// </summary>
	public class ApniUrduTranslator: Translator
	{
		private com.apniurdu.www.ApniUrdu apniUrduService;

		public ApniUrduTranslator(): base("Apni English To Urdu Translator", new string[,] {{"en", "ur"}})
		{
		}
		public override string Translate(string inputLanguage, string outputLanguage, string text)
		{
			if (! IsSupported(inputLanguage, outputLanguage))
				throw new LanguageCombinationNotSupportedException(
					"Language combination is not supported", inputLanguage, outputLanguage);

			if (apniUrduService == null)
				apniUrduService = new com.apniurdu.www.ApniUrdu();

			try
			{
				return apniUrduService.Translate(text);
			}
			catch (Exception exception)
			{
				throw new TranslationException("ApniUrdu WebService failed", exception);
			}
		}
	}
}
