// File           : LanguageCombinationNotSupportedException.cs
// Original Author: Guy Smith-Ferrier
// Date Created   : September 2005
// Notes          : This file is part of the downloadable source code for .NET Internationalization, by
//                  Guy Smith-Ferrier, published by Addison-Wesley. See http://www.dotneti18n.com for details.
// Disclaimer     : No warranty is provided. Use at your own risk.
// Modification   : You are free to modify this code providing that this block of comments is not altered
//                  and is placed before any code.
using System;
using System.Runtime.Serialization;

namespace Internationalization.Translation
{
	/// <summary>
	/// Summary description for LanguageCombinationNotSupported.
	/// </summary>
	[Serializable]
	public class LanguageCombinationNotSupportedException: TranslationException, ISerializable
	{
		private string inputLanguage;
		/// <summary>
		/// The input language
		/// </summary>
		public string InputLanguage
		{
			get {return inputLanguage;}
			set {inputLanguage = value;}
		}
		private string outputLanguage;
		/// <summary>
		/// The output language
		/// </summary>
		public string OutputLanguage
		{
			get {return outputLanguage;}
			set {outputLanguage = value;}
		}
		/// <summary>
		/// Constructs a new LanguageCombinationNotSupportedException
		/// </summary>
		public LanguageCombinationNotSupportedException(): base()
		{
		}
		/// <summary>
		/// Constructs a new LanguageCombinationNotSupportedException
		/// </summary>
		/// <param name="message">The message of the exception</param>
		public LanguageCombinationNotSupportedException(string message): base(message)
		{
		}
		/// <summary>
		/// Constructs a new LanguageCombinationNotSupportedException
		/// </summary>
		/// <param name="message">The message of the exception</param>
		/// <param name="inputLanguage">The input language</param>
		/// <param name="outputLanguage">The output language</param>
		public LanguageCombinationNotSupportedException(string message, string inputLanguage, string outputLanguage): base(message)
		{
			this.inputLanguage = inputLanguage;
			this.outputLanguage  = outputLanguage;
		}
        /// <summary>
        /// Constructs a new LanguageCombinationNotSupportedException
        /// </summary>
        /// <param name="info">The object that holds the serialized object data</param>
        /// <param name="context">The contextual information about the source or destination</param>
        public LanguageCombinationNotSupportedException(SerializationInfo info, StreamingContext context)
            : base(info, context)
		{
			inputLanguage = info.GetString("inputLanguage");
			outputLanguage  = info.GetString("outputLanguage" );
		}
        /// <summary>
        /// GetObjectData sets the SerializationInfo with information about the exception
        /// </summary>
        /// <param name="info">The object that holds the serialized object data</param>
        /// <param name="context">The contextual information about the source or destination</param>
        public override void GetObjectData(SerializationInfo info, StreamingContext context)
		{
			info.AddValue("inputLanguage", inputLanguage, typeof(String));
			info.AddValue("outputLanguage" , outputLanguage , typeof(String));
			base.GetObjectData(info, context);
		}
	}
}
