// File           : PigLatinTranslator.cs
// Original Author: Guy Smith-Ferrier
// Date Created   : September 2005
// Notes          : This file is part of the downloadable source code for .NET Internationalization, by
//                  Guy Smith-Ferrier, published by Addison-Wesley. See http://www.dotneti18n.com for details.
// Disclaimer     : No warranty is provided. Use at your own risk.
// Modification   : You are free to modify this code providing that this block of comments is not altered
//                  and is placed before any code.
using System;
using System.Text;

namespace Internationalization.Translation
{
	/// <summary>
    /// PigLatinTranslator is a translator which uses a translation service called PigLatin
	/// </summary>
    /// <remarks>The Pig Latin web service from aspxressway is no longer available. Do not use this translator.</remarks>
	public class PigLatinTranslator: Translator
	{
		private com.aspxpressway.www.piglatin pigLatinService;

        /// <summary>
        /// Constructs a PigLatinTranslator object
        /// </summary>
		public PigLatinTranslator(): base(PigLatinTranslatorResources.Name, 
			new string[,] {{"*", Internationalization.Common.PseudoTranslation.CultureInfo.Name}})
		{
		}
        /// <summary>
        /// Translate translates the input text from the input language to the output language
        /// </summary>
        /// <param name="inputLanguage">The language of the input text</param>
        /// <param name="outputLanguage">The language of the output text</param>
        /// <param name="text">The text to translate</param>
        /// <returns>The translated text</returns>
        public override string Translate(string inputLanguage, string outputLanguage, string text)
		{
			if (! IsSupported(inputLanguage, outputLanguage))
				throw new LanguageCombinationNotSupportedException(
					LanguageCombinationNotSupportedResources.LanguageCombinationNotSupported,
                    inputLanguage, outputLanguage);

			if (pigLatinService == null)
				pigLatinService = new com.aspxpressway.www.piglatin();

			string pigLatin = pigLatinService.toPigLatin(text);
			if (pigLatin.Length > 0 && pigLatin[0] == ' ' && text.Length > 0 && text[0] != ' ')
				// the Pig Latin web service prefixed the string with a space
				pigLatin = pigLatin.Substring(1);

			return pigLatin;
		}
	}
}
