// File           : TranslationException.cs
// Original Author: Guy Smith-Ferrier
// Date Created   : September 2005
// Notes          : This file is part of the downloadable source code for .NET Internationalization, by
//                  Guy Smith-Ferrier, published by Addison-Wesley. See http://www.dotneti18n.com for details.
// Disclaimer     : No warranty is provided. Use at your own risk.
// Modification   : You are free to modify this code providing that this block of comments is not altered
//                  and is placed before any code.
using System;
using System.Runtime.Serialization;

namespace Internationalization.Translation
{
	/// <summary>
	/// TranslationException is a generic exception thrown by ITranslator objects
	/// </summary>
	[Serializable]
	public class TranslationException: ApplicationException, ISerializable
	{
		/// <summary>
		/// Constructs a new TranslationException
		/// </summary>
		public TranslationException(): base()
		{
		}
		/// <summary>
		/// Constructs a new TranslationException
		/// </summary>
		/// <param name="message">The message of the exception</param>
		public TranslationException(string message): base(message)
		{
		}
		/// <summary>
		/// Constructs a TranslationException object
		/// </summary>
		/// <param name="message">The message of the exception</param>
		/// <param name="innerException">The value assigned to Exception.InnerException</param>
		public TranslationException(string message, Exception innerException): base(message, innerException)
		{
		}
        /// <summary>
        /// Constructs a TranslationException object
        /// </summary>
        /// <param name="info">The object that holds the serialized object data</param>
        /// <param name="context">The contextual information about the source or destination</param>
		public TranslationException(SerializationInfo info, StreamingContext context): base(info, context)
		{
		}
	}
}
