// File           : MainForm.cs
// Original Author: Guy Smith-Ferrier
// Date Created   : September 2005
// Notes          : This file is part of the downloadable source code for .NET Internationalization, by
//                  Guy Smith-Ferrier, published by Addison-Wesley. See http://www.dotneti18n.com for details.
// Disclaimer     : No warranty is provided. Use at your own risk.
// Modification   : You are free to modify this code providing that this block of comments is not altered
//                  and is placed before any code.
using System;
using System.Drawing;
using System.Collections;
using System.ComponentModel;
using System.Windows.Forms;
using System.Data;
using Internationalization.Translation;
using Internationalization.Translation.ResearchServices;
using System.Configuration;

namespace TranslatorEvaluator
{
	/// <summary>
	/// MainForm is the main form for the Translator Evaluator
	/// </summary>
	public class MainForm : System.Windows.Forms.Form
	{
		private TranslatorCollection translators;
		private DataTable dataTable;

		private System.Windows.Forms.GroupBox groupBox1;
		private System.Windows.Forms.GroupBox groupBox2;
		private System.Windows.Forms.Label label1;
		private System.Windows.Forms.Label label2;
		private System.Windows.Forms.TextBox textBoxFromLanguage;
		private System.Windows.Forms.TextBox textBoxToLanguage;
		private System.Windows.Forms.Label label3;
		private System.Windows.Forms.TextBox textBoxTranslationText;
		private System.Windows.Forms.Button buttonTranslate;
        private System.Windows.Forms.Button buttonShowSupport;
        private DataGridView dataGridViewTranslators;
		/// <summary>
		/// Required designer variable.
		/// </summary>
		private System.ComponentModel.Container components = null;

        /// <summary>
        /// Constructs a MainForm object
        /// </summary>
		public MainForm()
		{
			//
			// Required for Windows Form Designer support
			//
			InitializeComponent();

			InitializeTranslators();

			InitializeDataTable();

			InitializeDataGrid();
		}
		private void InitializeTranslators()
		{
			translators = new TranslatorCollection();
            translators.Add(new PseudoTranslator());

            string microsoftTranslatorApplicationId = ConfigurationManager.AppSettings["MicrosoftTranslatorApplicationId"];
            if (!String.IsNullOrEmpty(microsoftTranslatorApplicationId))
            {
                // there is an AppSetting for MicrosoftTranslatorApplicationId so add it as a translator
                MicrosoftTranslator.SearchApplicationId = microsoftTranslatorApplicationId;
                translators.Add(new MicrosoftTranslator());
            }

            // translators.Add(new WebServiceXTranslator());
			translators.Add(new CloserFarTranslator());
			translators.Add(new AltaVistaTranslator());
            translators.Add(new FreeTranslationTranslator());

            try
            {
                translators.Add(new Office2003ResearchServicesTranslator());
            }
            catch (TranslationException)
            {
                // Ignore this exception. This happens when running this program on a machine which
                // does not have Office 2003 installed on it or the Translation service has not been installed yet.
                // The consequence of this is that we simply don't add the Office 2003 Research Services Translator.
            }
            // translators.Add(new OnlineTranslator());
        }

		private DataTable CreateDataTable()
		{
			DataTable dataTable = new DataTable("Translators");

			dataTable.Columns.Add("Name");

			dataTable.Columns.Add("Supported");

			dataTable.Columns.Add("Duration");

			dataTable.Columns.Add("Translation");

			dataTable.Columns.Add("Translation Back");

			DataSet dataSet = new DataSet("Translators");
			dataSet.Tables.Add(dataTable);

			return dataTable;
		}

		private void InitializeDataTable()
		{
			dataTable = CreateDataTable();
			foreach(ITranslator translator in translators)
			{
				DataRow dataRow = dataTable.NewRow();
				dataRow["Name"            ] = translator.Name;
				dataRow["Supported"       ] = String.Empty;
				dataRow["Duration"        ] = String.Empty;
				dataRow["Translation"     ] = String.Empty;
				dataRow["Translation Back"] = String.Empty;
				dataTable.Rows.Add(dataRow);
			}
			dataTable.AcceptChanges();
		}

		private void InitializeDataGrid()
		{
            dataGridViewTranslators.DataSource = dataTable.DataSet;
            dataGridViewTranslators.DataMember = dataTable.TableName;
            dataGridViewTranslators.Columns["Name"].Width = 250;
            dataGridViewTranslators.Columns["Supported"].Width = 80;
            dataGridViewTranslators.Columns["Duration"].Width = 100;
            dataGridViewTranslators.Columns["Translation"].Width = 200;
            dataGridViewTranslators.Columns["Translation Back"].Width = 200;
        }

		/// <summary>
		/// Clean up any resources being used.
		/// </summary>
		protected override void Dispose( bool disposing )
		{
			if( disposing )
			{
				if (components != null) 
				{
					components.Dispose();
				}
			}
			base.Dispose( disposing );
		}

		#region Windows Form Designer generated code
		/// <summary>
		/// Required method for Designer support - do not modify
		/// the contents of this method with the code editor.
		/// </summary>
		private void InitializeComponent()
		{
            System.ComponentModel.ComponentResourceManager resources = new System.ComponentModel.ComponentResourceManager(typeof(MainForm));
            this.groupBox1 = new System.Windows.Forms.GroupBox();
            this.buttonTranslate = new System.Windows.Forms.Button();
            this.textBoxTranslationText = new System.Windows.Forms.TextBox();
            this.label3 = new System.Windows.Forms.Label();
            this.buttonShowSupport = new System.Windows.Forms.Button();
            this.textBoxToLanguage = new System.Windows.Forms.TextBox();
            this.textBoxFromLanguage = new System.Windows.Forms.TextBox();
            this.label2 = new System.Windows.Forms.Label();
            this.label1 = new System.Windows.Forms.Label();
            this.groupBox2 = new System.Windows.Forms.GroupBox();
            this.dataGridViewTranslators = new System.Windows.Forms.DataGridView();
            this.groupBox1.SuspendLayout();
            this.groupBox2.SuspendLayout();
            ((System.ComponentModel.ISupportInitialize)(this.dataGridViewTranslators)).BeginInit();
            this.SuspendLayout();
            // 
            // groupBox1
            // 
            this.groupBox1.Controls.Add(this.buttonTranslate);
            this.groupBox1.Controls.Add(this.textBoxTranslationText);
            this.groupBox1.Controls.Add(this.label3);
            this.groupBox1.Controls.Add(this.buttonShowSupport);
            this.groupBox1.Controls.Add(this.textBoxToLanguage);
            this.groupBox1.Controls.Add(this.textBoxFromLanguage);
            this.groupBox1.Controls.Add(this.label2);
            this.groupBox1.Controls.Add(this.label1);
            resources.ApplyResources(this.groupBox1, "groupBox1");
            this.groupBox1.Name = "groupBox1";
            this.groupBox1.TabStop = false;
            // 
            // buttonTranslate
            // 
            resources.ApplyResources(this.buttonTranslate, "buttonTranslate");
            this.buttonTranslate.Name = "buttonTranslate";
            this.buttonTranslate.Click += new System.EventHandler(this.buttonTranslate_Click);
            // 
            // textBoxTranslationText
            // 
            resources.ApplyResources(this.textBoxTranslationText, "textBoxTranslationText");
            this.textBoxTranslationText.Name = "textBoxTranslationText";
            // 
            // label3
            // 
            resources.ApplyResources(this.label3, "label3");
            this.label3.Name = "label3";
            // 
            // buttonShowSupport
            // 
            resources.ApplyResources(this.buttonShowSupport, "buttonShowSupport");
            this.buttonShowSupport.Name = "buttonShowSupport";
            this.buttonShowSupport.Click += new System.EventHandler(this.buttonShowSupport_Click);
            // 
            // textBoxToLanguage
            // 
            resources.ApplyResources(this.textBoxToLanguage, "textBoxToLanguage");
            this.textBoxToLanguage.Name = "textBoxToLanguage";
            // 
            // textBoxFromLanguage
            // 
            resources.ApplyResources(this.textBoxFromLanguage, "textBoxFromLanguage");
            this.textBoxFromLanguage.Name = "textBoxFromLanguage";
            // 
            // label2
            // 
            resources.ApplyResources(this.label2, "label2");
            this.label2.Name = "label2";
            // 
            // label1
            // 
            resources.ApplyResources(this.label1, "label1");
            this.label1.Name = "label1";
            // 
            // groupBox2
            // 
            this.groupBox2.Controls.Add(this.dataGridViewTranslators);
            resources.ApplyResources(this.groupBox2, "groupBox2");
            this.groupBox2.Name = "groupBox2";
            this.groupBox2.TabStop = false;
            // 
            // dataGridViewTranslators
            // 
            this.dataGridViewTranslators.AllowUserToAddRows = false;
            this.dataGridViewTranslators.AllowUserToDeleteRows = false;
            resources.ApplyResources(this.dataGridViewTranslators, "dataGridViewTranslators");
            this.dataGridViewTranslators.ColumnHeadersHeightSizeMode = System.Windows.Forms.DataGridViewColumnHeadersHeightSizeMode.AutoSize;
            this.dataGridViewTranslators.Name = "dataGridViewTranslators";
            this.dataGridViewTranslators.ReadOnly = true;
            // 
            // MainForm
            // 
            resources.ApplyResources(this, "$this");
            this.Controls.Add(this.groupBox2);
            this.Controls.Add(this.groupBox1);
            this.Name = "MainForm";
            this.groupBox1.ResumeLayout(false);
            this.groupBox1.PerformLayout();
            this.groupBox2.ResumeLayout(false);
            ((System.ComponentModel.ISupportInitialize)(this.dataGridViewTranslators)).EndInit();
            this.ResumeLayout(false);

		}
		#endregion

		/// <summary>
		/// The main entry point for the application.
		/// </summary>
		[STAThread]
		static void Main() 
		{
			Application.Run(new MainForm());
		}

        private void buttonTranslate_Click(object sender, System.EventArgs e)
        {
            int rowNumber;
            for (rowNumber = 0; rowNumber < translators.Count; rowNumber++)
            {
                DataRow dataRow = dataTable.Rows[rowNumber];
                dataRow["Duration"] = String.Empty;
                dataRow["Translation"] = String.Empty;
                dataRow["Translation Back"] = String.Empty;
            }
            rowNumber = 0;
            foreach (ITranslator translator in translators)
            {
                DataRow dataRow = dataTable.Rows[rowNumber++];

                if (translator.IsSupported(textBoxFromLanguage.Text, textBoxToLanguage.Text))
                {
                    dataRow["Supported"] = "Yes";
                    DateTime start = DateTime.Now;
                    try
                    {
                        string translatedText = translator.Translate(
                            textBoxFromLanguage.Text, textBoxToLanguage.Text, textBoxTranslationText.Text);

                        DateTime stop = DateTime.Now;
                        dataRow["Duration"] = (stop - start).ToString();
                        dataRow["Translation"] = translatedText;

                        if (translator.IsSupported(textBoxToLanguage.Text, textBoxFromLanguage.Text))
                        {
                            try
                            {
                                dataRow["Translation Back"] = translator.Translate(
                                    textBoxToLanguage.Text, textBoxFromLanguage.Text, translatedText);
                            }
                            catch (Exception exception)
                            {
                                dataRow["Translation Back"] =
                                    String.Format(MainFormResources.TranslationFailed, exception.Message);
                            }
                        }
                        else
                            dataRow["Translation Back"] = MainFormResources.NoSupportForThisDirection;

                    }
                    catch (Exception exception)
                    {
                        dataRow["Duration"] = String.Empty;
                        dataRow["Translation"] =
                            String.Format(MainFormResources.TranslationFailed, exception.Message);
                        dataRow["Translation Back"] = String.Empty;
                    }
                }
                else
                    dataRow["Supported"] = MainFormResources.No;
            }
        }

		private void buttonShowSupport_Click(object sender, System.EventArgs e)
		{
			int rowNumber = 0;
			foreach(ITranslator translator in translators)
			{
				DataRow dataRow = dataTable.Rows[rowNumber++];

				if (translator.IsSupported(textBoxFromLanguage.Text, textBoxToLanguage.Text))
					dataRow["Supported"] = MainFormResources.Yes;
				else
					dataRow["Supported"] = MainFormResources.No;

				dataRow["Duration"       ] = String.Empty;
				dataRow["Translation"    ] = String.Empty;
				dataRow["Translation Back"] = String.Empty;
			}
		}
	}
}
