// File           : Program.cs 
// Original Author: Guy Smith-Ferrier
// Date Created   : June 2008
// Notes          : This file is part of the downloadable source code for .NET Internationalization, by
//                  Guy Smith-Ferrier, published by Addison-Wesley. See http://www.dotneti18n.com for details.
// Disclaimer     : No warranty is provided. Use at your own risk.
// Modification   : You are free to modify this code providing that this block of comments is not altered
//                  and is placed before any code.
using System;
using System.Collections.Generic;
using System.Configuration;
using Internationalization.Common;

namespace ExportResources
{
    class Program
    {
        static void Main(string[] args)
        {
            Console.WriteLine("ExportResources - exports .NET resources from a source to a target");
            Console.WriteLine("");
            Internationalization.ResourceAdministration.ExportResources exportResources = 
                new Internationalization.ResourceAdministration.ExportResources();
            LoadConfiguration(exportResources);
            exportResources.ExportProgress = delegate(object sender,
                Internationalization.ResourceAdministration.ExportProgressEventArgs exportProgressEventArgs)
                {
                    System.Console.Write(".");
                };

            exportResources.Export();
            Console.WriteLine("Done.");
            Console.WriteLine("");
        }
        private static void LoadConfiguration(Internationalization.ResourceAdministration.ExportResources exportResources)
        {
            AppSettingsReader appSettingsReader = new AppSettingsReader();

            string targetLanguages = GetAppSettingsStringValue(appSettingsReader, "TargetLanguages");
            TargetLanguages.SetLanguages(targetLanguages.Split(new char[] { ',' }));

            exportResources.SourceResourcesGovernorTypeName =
                GetResourcesGovernorClassName(appSettingsReader, "SourceResourcesGovernor");

            exportResources.TargetResourcesGovernorTypeName =
                GetResourcesGovernorClassName(appSettingsReader, "TargetResourcesGovernor");

            exportResources.Source = GetAppSettingsStringValue(appSettingsReader, "Source");
            if (exportResources.Source == String.Empty)
                throw new ArgumentException("Source not found in appSettings");

            exportResources.Target = GetAppSettingsStringValue(appSettingsReader, "Target");
            if (exportResources.Target == String.Empty)
                throw new ArgumentException("Target not found in appSettings");

            exportResources.RecurseFolders = GetAppSettingsBooleanValue(appSettingsReader, "RecurseFolders", false);

            exportResources.AddPrefix = GetAppSettingsStringValue(appSettingsReader, "AddPrefix");

            exportResources.AddSuffix = GetAppSettingsStringValue(appSettingsReader, "AddSuffix");

            exportResources.IncludePrefixSuffixWhenEmpty =
                GetAppSettingsBooleanValue(appSettingsReader, "IncludePrefixSuffixWhenEmpty", false);

            exportResources.RemoveAppGlobalResourcesFolderName =
                GetAppSettingsBooleanValue(appSettingsReader, "RemoveAppGlobalResourcesFolderName", false);

            exportResources.RemoveAppLocalResourcesFolderName =
                GetAppSettingsBooleanValue(appSettingsReader, "RemoveAppLocalResourcesFolderName", false);
        }
        private static string GetResourcesGovernorClassName(AppSettingsReader appSettingsReader, string key)
        {
            string resourcesGovernorClassName = GetAppSettingsStringValue(appSettingsReader, key);
            if (resourcesGovernorClassName == String.Empty)
                resourcesGovernorClassName = "ResXResourcesGovernor";
            return resourcesGovernorClassName;
        }
        private static string GetAppSettingsStringValue(AppSettingsReader appSettingsReader, string key)
        {
            try
            {
                return appSettingsReader.GetValue(key, typeof(System.String)).ToString();
            }
            catch (InvalidOperationException)
            {
                return String.Empty;
            }
        }
        private static bool GetAppSettingsBooleanValue(AppSettingsReader appSettingsReader, string key, bool defaultValue)
        {
            string keyValue = GetAppSettingsStringValue(appSettingsReader, key);
            if (keyValue != String.Empty)
                return (keyValue == "1");
            else
                return defaultValue;
        }
    }
}
