// File           : ExportForm.cs 
// Original Author: Guy Smith-Ferrier
// Date Created   : September 2005
// Notes          : This file is part of the downloadable source code for .NET Internationalization, by
//                  Guy Smith-Ferrier, published by Addison-Wesley. See http://www.dotneti18n.com for details.
// Disclaimer     : No warranty is provided. Use at your own risk.
// Modification   : You are free to modify this code providing that this block of comments is not altered
//                  and is placed before any code.
using System;
using System.Drawing;
using System.Collections;
using System.ComponentModel;
using System.Windows.Forms;
using System.Globalization;
using System.Resources;
using Internationalization.ResourceAdministration;
using Internationalization.Common;

namespace Internationalization.ResourceAdministrator
{
	/// <summary>
	/// ExportForm allows the user to enter details to export resources to
	/// </summary>
	public class ExportForm : System.Windows.Forms.Form
	{
        private System.Windows.Forms.Label label3;
        private System.Windows.Forms.Button buttonFolderBrowserDialog;
        private System.Windows.Forms.Label label1;
        private System.Windows.Forms.Button buttonCancel;
        private System.Windows.Forms.Button buttonOK;
        private System.Windows.Forms.FolderBrowserDialog folderBrowserDialog;
		/// <summary>
		/// Required designer variable.
		/// </summary>
		private System.ComponentModel.Container components = null;

        private IResourcesGovernor sourceResourcesGovernor;
        private SetOfResourceSetsCollection sourceSetOfResourceSetsCollection;
        private System.Windows.Forms.TextBox textBoxResourcesTarget;
        private System.Windows.Forms.ComboBox comboBoxTargetResourcesGovernorClassName;
        private GroupBox groupBoxPrefixAndSuffix;
        private TextBox textBoxSuffix;
        private Label labelSuffix;
        private TextBox textBoxPrefix;
        private Label labelPrefix;
        private CheckBox checkBoxIncludeWhenEmpty;
        private Label label2;
        private TextBox textBoxBaseNamePrefix;
        private IResourcesGovernor targetResourcesGovernor;

        /// <summary>
        /// Constructs an ExportForm object
        /// </summary>
		public ExportForm()
		{
			InitializeComponent();
            foreach (string resourcesGovernorClassName in ResourcesGovernors.GetResourcesGovernorsTypeNames())
            {
                comboBoxTargetResourcesGovernorClassName.Items.Add(resourcesGovernorClassName);
            }
            comboBoxTargetResourcesGovernorClassName.SelectedIndex = 0;
		}
        /// <summary>
        /// Initializes an ExportForm object
        /// </summary>
        /// <param name="sourceResourcesGovernor">The IResourcesGovernor interface which represents the source of
        /// the resources</param>
        /// <param name="sourceSetOfResourceSetsCollection">The SetOfResourceSetsCollection to export</param>
        public void Initialize(IResourcesGovernor sourceResourcesGovernor, SetOfResourceSetsCollection sourceSetOfResourceSetsCollection)
		{
            this.sourceResourcesGovernor = sourceResourcesGovernor;
            this.sourceSetOfResourceSetsCollection = sourceSetOfResourceSetsCollection;
        }

		/// <summary>
		/// Clean up any resources being used.
		/// </summary>
		protected override void Dispose( bool disposing )
		{
			if( disposing )
			{
				if(components != null)
				{
					components.Dispose();
				}
			}
			base.Dispose( disposing );
		}

		#region Windows Form Designer generated code
		/// <summary>
		/// Required method for Designer support - do not modify
		/// the contents of this method with the code editor.
		/// </summary>
		private void InitializeComponent()
		{
            System.ComponentModel.ComponentResourceManager resources = new System.ComponentModel.ComponentResourceManager(typeof(ExportForm));
            this.comboBoxTargetResourcesGovernorClassName = new System.Windows.Forms.ComboBox();
            this.label3 = new System.Windows.Forms.Label();
            this.buttonFolderBrowserDialog = new System.Windows.Forms.Button();
            this.textBoxResourcesTarget = new System.Windows.Forms.TextBox();
            this.label1 = new System.Windows.Forms.Label();
            this.buttonCancel = new System.Windows.Forms.Button();
            this.buttonOK = new System.Windows.Forms.Button();
            this.folderBrowserDialog = new System.Windows.Forms.FolderBrowserDialog();
            this.groupBoxPrefixAndSuffix = new System.Windows.Forms.GroupBox();
            this.checkBoxIncludeWhenEmpty = new System.Windows.Forms.CheckBox();
            this.textBoxSuffix = new System.Windows.Forms.TextBox();
            this.labelSuffix = new System.Windows.Forms.Label();
            this.textBoxPrefix = new System.Windows.Forms.TextBox();
            this.labelPrefix = new System.Windows.Forms.Label();
            this.label2 = new System.Windows.Forms.Label();
            this.textBoxBaseNamePrefix = new System.Windows.Forms.TextBox();
            this.groupBoxPrefixAndSuffix.SuspendLayout();
            this.SuspendLayout();
            // 
            // comboBoxTargetResourcesGovernorClassName
            // 
            this.comboBoxTargetResourcesGovernorClassName.DropDownStyle = System.Windows.Forms.ComboBoxStyle.DropDownList;
            this.comboBoxTargetResourcesGovernorClassName.FormattingEnabled = true;
            resources.ApplyResources(this.comboBoxTargetResourcesGovernorClassName, "comboBoxTargetResourcesGovernorClassName");
            this.comboBoxTargetResourcesGovernorClassName.Name = "comboBoxTargetResourcesGovernorClassName";
            this.comboBoxTargetResourcesGovernorClassName.SelectedIndexChanged += new System.EventHandler(this.comboBoxResourcesGovernorClassName_SelectedIndexChanged);
            // 
            // label3
            // 
            resources.ApplyResources(this.label3, "label3");
            this.label3.Name = "label3";
            // 
            // buttonFolderBrowserDialog
            // 
            resources.ApplyResources(this.buttonFolderBrowserDialog, "buttonFolderBrowserDialog");
            this.buttonFolderBrowserDialog.Name = "buttonFolderBrowserDialog";
            this.buttonFolderBrowserDialog.Click += new System.EventHandler(this.buttonFolderBrowserDialog_Click);
            // 
            // textBoxResourcesTarget
            // 
            resources.ApplyResources(this.textBoxResourcesTarget, "textBoxResourcesTarget");
            this.textBoxResourcesTarget.Name = "textBoxResourcesTarget";
            this.textBoxResourcesTarget.Leave += new System.EventHandler(this.textBoxResourcesTarget_Leave);
            // 
            // label1
            // 
            resources.ApplyResources(this.label1, "label1");
            this.label1.Name = "label1";
            // 
            // buttonCancel
            // 
            this.buttonCancel.DialogResult = System.Windows.Forms.DialogResult.Cancel;
            resources.ApplyResources(this.buttonCancel, "buttonCancel");
            this.buttonCancel.Name = "buttonCancel";
            // 
            // buttonOK
            // 
            resources.ApplyResources(this.buttonOK, "buttonOK");
            this.buttonOK.Name = "buttonOK";
            this.buttonOK.Click += new System.EventHandler(this.buttonOK_Click);
            // 
            // groupBoxPrefixAndSuffix
            // 
            this.groupBoxPrefixAndSuffix.Controls.Add(this.checkBoxIncludeWhenEmpty);
            this.groupBoxPrefixAndSuffix.Controls.Add(this.textBoxSuffix);
            this.groupBoxPrefixAndSuffix.Controls.Add(this.labelSuffix);
            this.groupBoxPrefixAndSuffix.Controls.Add(this.textBoxPrefix);
            this.groupBoxPrefixAndSuffix.Controls.Add(this.labelPrefix);
            resources.ApplyResources(this.groupBoxPrefixAndSuffix, "groupBoxPrefixAndSuffix");
            this.groupBoxPrefixAndSuffix.Name = "groupBoxPrefixAndSuffix";
            this.groupBoxPrefixAndSuffix.TabStop = false;
            // 
            // checkBoxIncludeWhenEmpty
            // 
            resources.ApplyResources(this.checkBoxIncludeWhenEmpty, "checkBoxIncludeWhenEmpty");
            this.checkBoxIncludeWhenEmpty.Checked = true;
            this.checkBoxIncludeWhenEmpty.CheckState = System.Windows.Forms.CheckState.Checked;
            this.checkBoxIncludeWhenEmpty.Name = "checkBoxIncludeWhenEmpty";
            this.checkBoxIncludeWhenEmpty.UseVisualStyleBackColor = true;
            // 
            // textBoxSuffix
            // 
            resources.ApplyResources(this.textBoxSuffix, "textBoxSuffix");
            this.textBoxSuffix.Name = "textBoxSuffix";
            // 
            // labelSuffix
            // 
            resources.ApplyResources(this.labelSuffix, "labelSuffix");
            this.labelSuffix.Name = "labelSuffix";
            // 
            // textBoxPrefix
            // 
            resources.ApplyResources(this.textBoxPrefix, "textBoxPrefix");
            this.textBoxPrefix.Name = "textBoxPrefix";
            // 
            // labelPrefix
            // 
            resources.ApplyResources(this.labelPrefix, "labelPrefix");
            this.labelPrefix.Name = "labelPrefix";
            // 
            // label2
            // 
            resources.ApplyResources(this.label2, "label2");
            this.label2.Name = "label2";
            // 
            // textBoxBaseNamePrefix
            // 
            resources.ApplyResources(this.textBoxBaseNamePrefix, "textBoxBaseNamePrefix");
            this.textBoxBaseNamePrefix.Name = "textBoxBaseNamePrefix";
            // 
            // ExportForm
            // 
            this.AcceptButton = this.buttonOK;
            this.CancelButton = this.buttonCancel;
            resources.ApplyResources(this, "$this");
            this.Controls.Add(this.textBoxBaseNamePrefix);
            this.Controls.Add(this.label2);
            this.Controls.Add(this.groupBoxPrefixAndSuffix);
            this.Controls.Add(this.buttonCancel);
            this.Controls.Add(this.buttonOK);
            this.Controls.Add(this.comboBoxTargetResourcesGovernorClassName);
            this.Controls.Add(this.label3);
            this.Controls.Add(this.buttonFolderBrowserDialog);
            this.Controls.Add(this.textBoxResourcesTarget);
            this.Controls.Add(this.label1);
            this.Name = "ExportForm";
            this.groupBoxPrefixAndSuffix.ResumeLayout(false);
            this.groupBoxPrefixAndSuffix.PerformLayout();
            this.ResumeLayout(false);
            this.PerformLayout();

        }
		#endregion

        /// <summary>
        /// TargetResourcesGovernorClassName is the name of the class of the target resources governor
        /// </summary>
        public string TargetResourcesGovernorClassName
        {
            get {return comboBoxTargetResourcesGovernorClassName.Text;}
            set {comboBoxTargetResourcesGovernorClassName.Text = value;}
        }
        /// <summary>
        /// Target is the target for the exported resources
        /// </summary>
        /// <remarks>The exact contents of Target depends on the TargetResourcesGovernorClassName. For file
        /// based resource governors this is a path. For database based resource governors this is a
        /// connection string.</remarks>
        public string Target
        {
            get {return textBoxResourcesTarget.Text;}
            set {textBoxResourcesTarget.Text = value;}
        }

        /// <summary>
        /// SetResourcesGovernor sets the internal resources governor
        /// </summary>
        protected virtual void SetResourcesGovernor()
        {
            targetResourcesGovernor = ResourceAdministrationHelper.CreateResourcesGovernor(TargetResourcesGovernorClassName, Target);
            buttonFolderBrowserDialog.Enabled = targetResourcesGovernor.IsFileBased;
        }

        private void buttonFolderBrowserDialog_Click(object sender, System.EventArgs e)
        {
            folderBrowserDialog.SelectedPath = textBoxResourcesTarget.Text;
            if (folderBrowserDialog.ShowDialog() == DialogResult.OK)
                textBoxResourcesTarget.Text = folderBrowserDialog.SelectedPath;
        }

        private void textBoxResourcesTarget_Leave(object sender, System.EventArgs e)
        {
            SetResourcesGovernor();
        }

        private void comboBoxResourcesGovernorClassName_SelectedIndexChanged(object sender, System.EventArgs e)
        {
            SetResourcesGovernor();
        }

        private void buttonOK_Click(object sender, System.EventArgs e)
        {
            if (Target == String.Empty)
                MessageBox.Show(ExportFormResources.TargetOfResourcesMustNotBeEmpty);
            else
            {
                bool targetExists = true;
                if (! targetResourcesGovernor.Exists)
                {
                    if (MessageBox.Show(ExportFormResources.TargetDoesNotExist, "", MessageBoxButtons.YesNo) == DialogResult.Yes)
                    {
                        try
                        {
                            targetResourcesGovernor.Create();
                        }
                        catch (Exception exception)
                        {
                            targetExists = false;
                            MessageBox.Show(ExportFormResources.UnableToCreateTheSource +
                                System.Environment.NewLine + System.Environment.NewLine +
                                "(" + exception.Message + ")" +
                                System.Environment.NewLine + System.Environment.NewLine +
                                ExportFormResources.NoExportHasOccurred);
                        }
                    }
                    else
                    {
                        targetExists = false;
                        MessageBox.Show(ExportFormResources.NoExportOccurredTargetDoesNotExist);
                    }
                }
                if (targetExists && MessageBox.Show(ExportFormResources.ExportResources) == DialogResult.OK)
                {
                    Export();
                    MessageBox.Show(ExportFormResources.ExportComplete);
                    DialogResult = DialogResult.OK;
                }
            }
        }
        private bool Export()
        {
            ProgressForm progress = new ProgressForm();
            try
            {
                progress.Show();

                GetSetOfResourceSets getSetOfResourceSets = delegate(string baseName)
                {
                    return sourceSetOfResourceSetsCollection.GetSetOfResourceSets(baseName);
                };

                ExportProgress exportProgress = delegate(object sender, ExportProgressEventArgs args)
                {
                    progress.Text = String.Format(ExportFormResources.Exporting, args.BaseName);
                    progress.Maximum = args.Maximum;
                    progress.Value = args.Position;
                };

                return ResourceAdministrationHelper.ExportResources(
                    sourceResourcesGovernor,
                    targetResourcesGovernor,
                    getSetOfResourceSets,
                    exportProgress,
                    textBoxBaseNamePrefix.Text,
                    textBoxPrefix.Text,
                    textBoxSuffix.Text,
                    checkBoxIncludeWhenEmpty.Checked);
            }
            catch (Exception exception)
            {
                MessageBox.Show(ExportFormResources.AnExceptionHasOccured +
                    System.Environment.NewLine + System.Environment.NewLine +
                    exception.GetType().Name + ": " + exception.Message);
                return false;
            }
            finally
            {
                progress.Close();
            }
        }
    }
}
