// File           : CreateMissingResourcesForm.cs 
// Original Author: Guy Smith-Ferrier
// Date Created   : September 2005
// Notes          : This file is part of the downloadable source code for .NET Internationalization, by
//                  Guy Smith-Ferrier, published by Addison-Wesley. See http://www.dotneti18n.com for details.
// Disclaimer     : No warranty is provided. Use at your own risk.
// Modification   : You are free to modify this code providing that this block of comments is not altered
//                  and is placed before any code.
using System;
using System.Drawing;
using System.Collections;
using System.ComponentModel;
using System.Windows.Forms;
using System.Globalization;

namespace Internationalization.ResourceAdministration
{
	/// <summary>
	/// CreateMissingResourcesForm offers a list of missing resources and allows the user to select them
	/// </summary>
	public class CreateMissingResourcesForm : System.Windows.Forms.Form
	{
		private CultureInfo[] missingResources;

		private System.Windows.Forms.Panel panel1;
		private System.Windows.Forms.Button buttonOK;
		private System.Windows.Forms.Button buttonCancel;
		private System.Windows.Forms.GroupBox groupBox1;
		private System.Windows.Forms.CheckedListBox checkedListBoxMissingResources;
		/// <summary>
		/// Required designer variable.
		/// </summary>
		private System.ComponentModel.Container components = null;

        /// <summary>
        /// Constructs a CreateMissingResourcesForm object
        /// </summary>
		public CreateMissingResourcesForm()
		{
			InitializeComponent();
		}

		/// <summary>
		/// Clean up any resources being used.
		/// </summary>
		protected override void Dispose( bool disposing )
		{
			if( disposing )
			{
				if(components != null)
				{
					components.Dispose();
				}
			}
			base.Dispose( disposing );
		}

		#region Windows Form Designer generated code
		/// <summary>
		/// Required method for Designer support - do not modify
		/// the contents of this method with the code editor.
		/// </summary>
		private void InitializeComponent()
		{
            System.ComponentModel.ComponentResourceManager resources = new System.ComponentModel.ComponentResourceManager(typeof(CreateMissingResourcesForm));
            this.panel1 = new System.Windows.Forms.Panel();
            this.buttonCancel = new System.Windows.Forms.Button();
            this.buttonOK = new System.Windows.Forms.Button();
            this.groupBox1 = new System.Windows.Forms.GroupBox();
            this.checkedListBoxMissingResources = new System.Windows.Forms.CheckedListBox();
            this.panel1.SuspendLayout();
            this.groupBox1.SuspendLayout();
            this.SuspendLayout();
            // 
            // panel1
            // 
            this.panel1.Controls.Add(this.buttonCancel);
            this.panel1.Controls.Add(this.buttonOK);
            resources.ApplyResources(this.panel1, "panel1");
            this.panel1.Name = "panel1";
            // 
            // buttonCancel
            // 
            this.buttonCancel.DialogResult = System.Windows.Forms.DialogResult.Cancel;
            resources.ApplyResources(this.buttonCancel, "buttonCancel");
            this.buttonCancel.Name = "buttonCancel";
            // 
            // buttonOK
            // 
            this.buttonOK.DialogResult = System.Windows.Forms.DialogResult.OK;
            resources.ApplyResources(this.buttonOK, "buttonOK");
            this.buttonOK.Name = "buttonOK";
            // 
            // groupBox1
            // 
            this.groupBox1.Controls.Add(this.checkedListBoxMissingResources);
            resources.ApplyResources(this.groupBox1, "groupBox1");
            this.groupBox1.Name = "groupBox1";
            this.groupBox1.TabStop = false;
            // 
            // checkedListBoxMissingResources
            // 
            resources.ApplyResources(this.checkedListBoxMissingResources, "checkedListBoxMissingResources");
            this.checkedListBoxMissingResources.Name = "checkedListBoxMissingResources";
            // 
            // CreateMissingResourcesForm
            // 
            this.AcceptButton = this.buttonOK;
            this.CancelButton = this.buttonCancel;
            resources.ApplyResources(this, "$this");
            this.Controls.Add(this.groupBox1);
            this.Controls.Add(this.panel1);
            this.Name = "CreateMissingResourcesForm";
            this.panel1.ResumeLayout(false);
            this.groupBox1.ResumeLayout(false);
            this.ResumeLayout(false);

		}
		#endregion

        /// <summary>
        /// MissingResources is an array of CultureInfo objects representing the missing resources
        /// </summary>
		public CultureInfo[] MissingResources
		{
			get {return missingResources;}
			set
			{
				missingResources = value;
				checkedListBoxMissingResources.Items.Clear();
				foreach(CultureInfo missingResource in missingResources)
				{
					checkedListBoxMissingResources.Items.Add(missingResource.DisplayName, true);
				}
			}
		}
        /// <summary>
        /// CheckedMissingResources is an array of CultureInfo objects representing the missing resources which
        /// have been checked
        /// </summary>
		public CultureInfo[] CheckedMissingResources
		{
			get
			{
				CultureInfo[] checkedMissingResources = new CultureInfo[checkedListBoxMissingResources.Items.Count];
				int cultureInfoNumber = 0;
				foreach(int index in checkedListBoxMissingResources.CheckedIndices)
				{
					// the missingResources array is in parallel with the checked list box
					// so we can use the index from the checked list box with the missingResources array
					checkedMissingResources[cultureInfoNumber++] = missingResources[index];
				}
				return checkedMissingResources;
			}
		}
	}
}
