// File           : ResourcesDataNode.cs
// Original Author: Guy Smith-Ferrier
// Date Created   : September 2005
// Notes          : This file is part of the downloadable source code for .NET Internationalization, by
//                  Guy Smith-Ferrier, published by Addison-Wesley. See http://www.dotneti18n.com for details.
// Disclaimer     : No warranty is provided. Use at your own risk.
// Modification   : You are free to modify this code providing that this block of comments is not altered
//                  and is placed before any code.
using System;
using System.Text;

namespace Internationalization.ResourceAdministration
{
    /// <summary>
    /// IResourcesDataNode is an interface for describing a resources data node
    /// </summary>
    public interface IResourcesDataNode
    {
        /// <summary>
        /// A comment about the resource entry
        /// </summary>
        string Comment { get; set; }
        /// <summary>
        /// The name of the resource entry
        /// </summary>
        string Name { get; set; }
        /// <summary>
        /// The value of the resource entry
        /// </summary>
        object Value { get; set; }
        /// <summary>
        /// The IResourcesFileRef of the resource entry
        /// </summary>
        IResourcesFileRef FileRef { get; set; }
    }

    /// <summary>
    /// ResourcesDataNode is a generic implementation of a resources data node
    /// </summary>
    /// <remarks>ResourcesDataNode is suitable for use with resource managers which need to support
    /// data nodes but which do not have a data node class (such as ResXDataNode)</remarks>
    public class ResourcesDataNode: IResourcesDataNode
    {
        private string comment;
        private string name;
        private object dataValue;
        private IResourcesFileRef fileRef;

        /// <summary>
        /// Constructs a ResourcesDataNode object
        /// </summary>
        /// <param name="name">The name of the resource entry</param>
        /// <param name="value">The value of the resource entry</param>
        public ResourcesDataNode(string name, object value)
        {
            this.name = name;
            this.dataValue = value;
        }
        /// <summary>
        /// A comment about the resource entry
        /// </summary>
        public string Comment
        {
            get { return comment; }
            set { comment = value; }
        }
        /// <summary>
        /// The name of the resource entry
        /// </summary>
        public string Name
        {
            get { return name; }
            set { name = value; }
        }
        /// <summary>
        /// The value of the resource entry
        /// </summary>
        public object Value
        {
            get { return dataValue; }
            set { dataValue = value; }
        }
        /// <summary>
        /// The IResourcesFileRef of the resource entry
        /// </summary>
        public IResourcesFileRef FileRef
        {
            get { return fileRef; }
            set { fileRef = value; }
        }
    }
}
