﻿using System;
using System.Collections.Generic;
using System.IO;
using System.Text;
using Microsoft.Build.Framework;

namespace Silverlight.Build.Tasks
{
    public class XapResourcePackager: XapResourcePackagerBase
    {
        public override bool Execute()
        {
            if (String.IsNullOrEmpty(this.PackageCultures) || this.PackageCultures.Split(',').GetLength(0) == 0)
            {
                return true;
            }

            this.PackageCultures = this.PackageCultures.Replace(((char)10).ToString(), "");
            this.PackageCultures = this.PackageCultures.Replace(((char)13).ToString(), "");

            List<string> xapOutputFiles = new List<string>();
            foreach (string packageCulture in this.PackageCultures.Split(','))
            {
                if (!String.IsNullOrEmpty(packageCulture))
                {
                    string xapResourceFilename = String.Format("{0}.{1}.xap", this.XapFilenameWithoutExtension, packageCulture);
                    xapResourceFilename = Path.Combine(this.TargetDir, xapResourceFilename);
                    this.Log.LogMessage("Creating XAP Resource file {0}", xapResourceFilename);
                    ZipFile zipFile = new ZipFile(xapResourceFilename);
                    zipFile.Create();
                    try
                    {
                        this.Log.LogMessage("Adding AppManifest.xaml");
                        AddAppManifest(zipFile, packageCulture);

                        this.Log.LogMessage("Adding Satellite Resource Assembly");
                        AddResourceAssembly(zipFile, packageCulture);

                        this.Log.LogMessage("Xap packaging completed successfully");
                    }
                    finally
                    {
                        zipFile.Close();
                    }

                    xapOutputFiles.Add(xapResourceFilename);
                }
            }

            this.XapOutputFiles = xapOutputFiles.ToArray();

            return true;
        }

        protected void AddResourceAssembly(ZipFile zipFile, string packageCulture)
        {
            string entryName = String.Format(@"{0}\{1}.resources.dll", packageCulture, this.XapFilenameWithoutExtension);
            string sourceFile = Path.Combine(this.TargetDir, entryName);
            zipFile.AddFile(sourceFile, entryName);
        }

        protected string GetResourcesAssemblyPath(string packageCulture)
        {
            return String.Format("{0}/{1}.resources.dll", packageCulture, this.XapFilenameWithoutExtension);
        }

        private void AddAppManifest(ZipFile zipFile, string packageCulture)
        {
            string appManifest = String.Format(
                @"<Deployment xmlns=""http://schemas.microsoft.com/client/2007/deployment"" " +
                @"xmlns:x=""http://schemas.microsoft.com/winfx/2006/xaml"">" + System.Environment.NewLine +
                @"  <Deployment.Parts>" + System.Environment.NewLine +
                @"    <AssemblyPart Source=""{0}"" />" + System.Environment.NewLine +
                @"  </Deployment.Parts>" + System.Environment.NewLine +
                @"</Deployment>",
                this.GetResourcesAssemblyPath(packageCulture));

            zipFile.AddEntry("AppManifest.xaml", Encoding.ASCII.GetBytes(appManifest));
        }
    }
}
