﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.IO;
using System.IO.Packaging;
using System.Net.Mime;

namespace Silverlight.Build.Tasks
{
    // The downside of using the Package class is that it creates an additional file
    // called "[Content_Types].xml". It is not possible to prevent this file from
    // being added.
    public class ZipFile
    {
        private Package package;

        public ZipFile(string filename)
        {
            this.Filename = filename;
        }

        public string Filename { get; set; }

        public void Create()
        {
            this.package = Package.Open(this.Filename, FileMode.Create);
        }

        public void AddEntry(string entryName, byte[] entry)
        {
            using (MemoryStream stream = new MemoryStream())
            {
                stream.Write(entry, 0, entry.Length);
                stream.Position = 0;
                AddStream(entryName, stream);
            }
        }

        public void AddFile(string file, string entryName)
        {
            using (FileStream fileStream =
                new FileStream(file, FileMode.Open, FileAccess.Read))
            {
                AddStream(entryName, fileStream);
            }
        }

        private void AddStream(string path, Stream stream)
        {
            Uri uri = PackUriHelper.CreatePartUri(new Uri(path, UriKind.Relative));

            PackagePart packagePart = package.CreatePart(uri, MediaTypeNames.Text.Plain);

            CopyStream(stream, packagePart.GetStream());
        }

        private static void CopyStream(Stream source, Stream target)
        {
            const int bufSize = 0x1000;
            byte[] bytes = new byte[bufSize];
            int bytesRead = 0;
            while ((bytesRead = source.Read(bytes, 0, bufSize)) > 0)
            {
                target.Write(bytes, 0, bytesRead);
            }
        }

        public void Close()
        {
            package.Close();
        }
    }
}
