﻿// File           : DoNotDoNotUseMethod.cs 
// Original Author: Guy Smith-Ferrier
// Date Created   : April 2013
// Notes          : This file is part of the downloadable source code for .NET Internationalization, by
//                  Guy Smith-Ferrier, published by Addison-Wesley. See http://www.dotneti18n.com for details.
// Disclaimer     : No warranty is provided. Use at your own risk.
// Modification   : You are free to modify this code providing that this block of comments is not altered
//                  and is placed before any code.
using Microsoft.FxCop.Sdk;

namespace GlobalizationRules
{
    /// <summary>
    /// DoNotUseMethod is a rule to identify when a specific method is invoked
    /// </summary>
    public class DoNotUseMethod : BaseGlobalizationRule
    {
        private string memberFullName;

        /// <summary>
        /// Constructs an DoNotUseMethod object
        /// </summary>
        /// <param name="ruleName">The name of the rule</param>
        /// <param name="memberFullName">The complete method signature to look for</param>
        public DoNotUseMethod(string ruleName, string memberFullName) :
            base(ruleName)
        {
            this.memberFullName = memberFullName;
        }

        /// <summary>
        /// Check checks members for adherence to the rule
        /// </summary>
        /// <param name="member">The Member to check</param>
        /// <returns>The ProblemCollection of problems found by this method</returns>
        public override ProblemCollection Check(Member member)
        {
            Method method = member as Method;
            if (method != null)
            {
                VisitMethod(method);
            }

            return this.Problems;
        }

        /// <summary>
        /// VisitExpression is called by the FxCop engine to visit every expression in scope
        /// </summary>
        /// <param name="expression">The Expression that is being visited</param>
        public override void VisitExpression(Expression expression)
        {
            if (expression is MethodCall)
            {
                MethodCall methodCall = (MethodCall)expression;
                if (methodCall.Callee is MemberBinding)
                {
                    MemberBinding calleeMemberBinding = (MemberBinding)methodCall.Callee;
                    if (calleeMemberBinding.BoundMember.FullName.StartsWith(this.memberFullName + "(") ||
                        calleeMemberBinding.BoundMember.FullName == this.memberFullName)
                    {
                        Resolution resolution = GetResolution();
                        Problems.Add(new Problem(resolution));
                    }
                }
            }

            base.VisitExpression(expression);
        }
    }
}
