// File           : EnumToStringIsNotLocalizable.cs
// Original Author: Guy Smith-Ferrier
// Date Created   : April 2008
// Notes          : This file is part of the downloadable source code for .NET Internationalization, by
//                  Guy Smith-Ferrier, published by Addison-Wesley. See http://www.dotneti18n.com for details.
// Disclaimer     : No warranty is provided. Use at your own risk.
// Modification   : You are free to modify this code providing that this block of comments is not altered
//                  and is placed before any code.
using System;
using System.Collections.Specialized;
using System.Text;
using Microsoft.FxCop.Sdk;

namespace GlobalizationRules
{
    /// <summary>
    /// EnumToStringIsNotLocalizable checks against the use of Enum.ToString()
    /// </summary>
    public class EnumToStringIsNotLocalizable : BaseGlobalizationRule
    {
        /// <summary>
        /// Constructs an EnumToStringIsNotLocalizable object
        /// </summary>
        public EnumToStringIsNotLocalizable():
            base("EnumToStringIsNotLocalizable")
        {
        }
        /// <summary>
        /// Check checks members for adherence to the rule
        /// </summary>
        /// <param name="member">The Member to check</param>
        /// <returns>The ProblemCollection of problems found by this method</returns>
        public override ProblemCollection Check(Member member)
        {
            Method method = member as Method;
            if (method == null)
                return null;

            VisitMethod(method);

            return Problems;
        }
        /// <summary>
        /// VisitMethodCall is called for each call to a method
        /// </summary>
        /// <param name="call">The MethodCall of the method that is being called</param>
        public override void VisitMethodCall(MethodCall call)
        {
            if (call != null && call.Callee != null && call.Callee is MemberBinding)
            {
                Expression targetObject = ((MemberBinding)call.Callee).TargetObject;
                if (targetObject != null && targetObject.Type != null && targetObject.Type.Name.Name == "Enum")
                {
                    MemberBinding calleeExpression = (MemberBinding)call.Callee;
                    if (calleeExpression != null &&
                        calleeExpression.BoundMember.FullName == "System.Object.ToString")
                    {
                        Resolution resolution = GetResolution(
                            new string[] { ((BinaryExpression)targetObject).Operand2.ToString() });
                        Problems.Add(new Problem(resolution));
                    }
                }
            }
            base.VisitMethodCall(call);
        }
    }
}
