// File           : RestrictedIdentifierName.cs
// Original Author: Guy Smith-Ferrier
// Date Created   : April 2013
// Notes          : This file is part of the downloadable source code for .NET Internationalization, by
//                  Guy Smith-Ferrier, published by Addison-Wesley. See http://www.dotneti18n.com for details.
// Disclaimer     : No warranty is provided. Use at your own risk.
// Modification   : You are free to modify this code providing that this block of comments is not altered
//                  and is placed before any code.
using System;
using System.Collections.Specialized;
using System.Text;
using Microsoft.FxCop.Sdk;

namespace GlobalizationRules
{
    /// <summary>
    /// RestrictedIdentifierName checks against the use of a restricted name as an identifier
    /// </summary>
    public class RestrictedIdentifierName : BaseGlobalizationRule
    {
        private string restrictedIdentifier;

        /// <summary>
        /// Constructs a RestrictedIdentifierName object
        /// </summary>
        public RestrictedIdentifierName(string ruleName, string restrictedIdentifier) :
            base(ruleName)
        {
            this.restrictedIdentifier = restrictedIdentifier;
        }

        /// <summary>
        /// Check checks members for adherence to the rule
        /// </summary>
        /// <param name="member">The Member to check</param>
        /// <returns>The ProblemCollection of problems found by this method</returns>
        public override ProblemCollection Check(Member member)
        {
            base.Check(member);

            CheckIdentifier(member.Name.Name);

            return Problems;
        }

        /// <summary>
        /// CheckIdentifier checks that an identifier is not a restricted identifier
        /// </summary>
        /// <param name="identifier"></param>
        private void CheckIdentifier(string identifier)
        {
            string simplifiedIdentifier = identifier.Replace("_", string.Empty);

            if (string.Compare(simplifiedIdentifier, restrictedIdentifier, StringComparison.InvariantCultureIgnoreCase) == 0)
            {
                Resolution resolution = GetResolution();
                Problems.Add(new Problem(resolution));
            }
        }
    }
}
