// File           : ResourcesSourceForm.cs
// Original Author: Guy Smith-Ferrier
// Date Created   : September 2005
// Notes          : This file is part of the downloadable source code for .NET Internationalization, by
//                  Guy Smith-Ferrier, published by Addison-Wesley. See http://www.dotneti18n.com for details.
// Disclaimer     : No warranty is provided. Use at your own risk.
// Modification   : You are free to modify this code providing that this block of comments is not altered
//                  and is placed before any code.
using System;
using System.Drawing;
using System.Collections;
using System.ComponentModel;
using System.Windows.Forms;
using System.Globalization;
using System.IO;
using Internationalization.ResourceAdministration;

namespace ResourceTranslationManager
{
	/// <summary>
    /// ResourcesSourceForm allows the user to specify the source of the resources
	/// </summary>
	public class ResourcesSourceForm : System.Windows.Forms.Form
	{
        private System.Windows.Forms.Label label1;
        private System.Windows.Forms.TextBox textBoxResourcesSource;
        private System.Windows.Forms.Label label2;
        private System.Windows.Forms.TextBox textBoxTargetLanguage;
        private System.Windows.Forms.Button buttonOK;
        private System.Windows.Forms.Button buttonCancel;
        private System.Windows.Forms.FolderBrowserDialog folderBrowserDialog;
        private System.Windows.Forms.Button buttonFolderBrowserDialog;
        private System.Windows.Forms.Label label3;
        private System.Windows.Forms.ComboBox comboBoxResourcesGovernorClassName;
		/// <summary>
		/// Required designer variable.
		/// </summary>
		private System.ComponentModel.Container components = null;

        private IResourcesGovernor resourcesGovernor;

        /// <summary>
        /// Constructs a ResourcesSourceForm object
        /// </summary>
		public ResourcesSourceForm()
		{
			InitializeComponent();
		}

		/// <summary>
		/// Clean up any resources being used.
		/// </summary>
		protected override void Dispose( bool disposing )
		{
			if( disposing )
			{
				if(components != null)
				{
					components.Dispose();
				}
			}
			base.Dispose( disposing );
		}

		#region Windows Form Designer generated code
		/// <summary>
		/// Required method for Designer support - do not modify
		/// the contents of this method with the code editor.
		/// </summary>
		private void InitializeComponent()
		{
            System.ComponentModel.ComponentResourceManager resources = new System.ComponentModel.ComponentResourceManager(typeof(ResourcesSourceForm));
            this.label1 = new System.Windows.Forms.Label();
            this.textBoxResourcesSource = new System.Windows.Forms.TextBox();
            this.label2 = new System.Windows.Forms.Label();
            this.textBoxTargetLanguage = new System.Windows.Forms.TextBox();
            this.buttonOK = new System.Windows.Forms.Button();
            this.buttonCancel = new System.Windows.Forms.Button();
            this.folderBrowserDialog = new System.Windows.Forms.FolderBrowserDialog();
            this.buttonFolderBrowserDialog = new System.Windows.Forms.Button();
            this.label3 = new System.Windows.Forms.Label();
            this.comboBoxResourcesGovernorClassName = new System.Windows.Forms.ComboBox();
            this.SuspendLayout();
            // 
            // label1
            // 
            resources.ApplyResources(this.label1, "label1");
            this.label1.Name = "label1";
            // 
            // textBoxResourcesSource
            // 
            resources.ApplyResources(this.textBoxResourcesSource, "textBoxResourcesSource");
            this.textBoxResourcesSource.Name = "textBoxResourcesSource";
            this.textBoxResourcesSource.Leave += new System.EventHandler(this.textBoxResourcesSource_Leave);
            // 
            // label2
            // 
            resources.ApplyResources(this.label2, "label2");
            this.label2.Name = "label2";
            // 
            // textBoxTargetLanguage
            // 
            resources.ApplyResources(this.textBoxTargetLanguage, "textBoxTargetLanguage");
            this.textBoxTargetLanguage.Name = "textBoxTargetLanguage";
            // 
            // buttonOK
            // 
            resources.ApplyResources(this.buttonOK, "buttonOK");
            this.buttonOK.Name = "buttonOK";
            this.buttonOK.Click += new System.EventHandler(this.buttonOK_Click);
            // 
            // buttonCancel
            // 
            this.buttonCancel.DialogResult = System.Windows.Forms.DialogResult.Cancel;
            resources.ApplyResources(this.buttonCancel, "buttonCancel");
            this.buttonCancel.Name = "buttonCancel";
            // 
            // buttonFolderBrowserDialog
            // 
            resources.ApplyResources(this.buttonFolderBrowserDialog, "buttonFolderBrowserDialog");
            this.buttonFolderBrowserDialog.Name = "buttonFolderBrowserDialog";
            this.buttonFolderBrowserDialog.Click += new System.EventHandler(this.buttonFolderBrowserDialog_Click);
            // 
            // label3
            // 
            resources.ApplyResources(this.label3, "label3");
            this.label3.Name = "label3";
            // 
            // comboBoxResourcesGovernorClassName
            // 
            this.comboBoxResourcesGovernorClassName.DropDownStyle = System.Windows.Forms.ComboBoxStyle.DropDownList;
            this.comboBoxResourcesGovernorClassName.FormattingEnabled = true;
            this.comboBoxResourcesGovernorClassName.Items.AddRange(new object[] {
            resources.GetString("comboBoxResourcesGovernorClassName.Items"),
            resources.GetString("comboBoxResourcesGovernorClassName.Items1"),
            resources.GetString("comboBoxResourcesGovernorClassName.Items2")});
            resources.ApplyResources(this.comboBoxResourcesGovernorClassName, "comboBoxResourcesGovernorClassName");
            this.comboBoxResourcesGovernorClassName.Name = "comboBoxResourcesGovernorClassName";
            this.comboBoxResourcesGovernorClassName.SelectedIndexChanged += new System.EventHandler(this.comboBoxResourcesGovernorClassName_SelectedIndexChanged);
            // 
            // ResourcesSourceForm
            // 
            this.AcceptButton = this.buttonOK;
            this.CancelButton = this.buttonCancel;
            resources.ApplyResources(this, "$this");
            this.Controls.Add(this.comboBoxResourcesGovernorClassName);
            this.Controls.Add(this.label3);
            this.Controls.Add(this.buttonFolderBrowserDialog);
            this.Controls.Add(this.buttonCancel);
            this.Controls.Add(this.buttonOK);
            this.Controls.Add(this.textBoxTargetLanguage);
            this.Controls.Add(this.label2);
            this.Controls.Add(this.textBoxResourcesSource);
            this.Controls.Add(this.label1);
            this.Name = "ResourcesSourceForm";
            this.ResumeLayout(false);
            this.PerformLayout();

        }
		#endregion

        private void buttonOK_Click(object sender, System.EventArgs e)
        {
            if (textBoxTargetLanguage.Text.Trim() == String.Empty)
                MessageBox.Show(ResourcesSourcesFormResources.TargetNameMustNotBeEmpty);
            else if (! IsValidCulture(textBoxTargetLanguage.Text))
                MessageBox.Show(ResourcesSourcesFormResources.TargetNameMustBeValid);
            else if (Source == String.Empty)
                MessageBox.Show(ResourcesSourcesFormResources.SourceMustNotBeEmpty);
            else if (!resourcesGovernor.IsFileBased && Directory.Exists(Source))
                MessageBox.Show(ResourcesSourcesFormResources.ResourcesGovernorMismatchWithSource);
            else if (!resourcesGovernor.Exists)
                MessageBox.Show(ResourcesSourcesFormResources.SourceDoesNotExist);
            else
                DialogResult = DialogResult.OK;
        }
        private bool IsValidCulture(string cultureName)
        {
            try
            {
                CultureInfo cultureInfo = new CultureInfo(cultureName);
                return true;
            }
            catch (ArgumentException)
            {
                return false;
            }
        }

        private void buttonFolderBrowserDialog_Click(object sender, System.EventArgs e)
        {
            folderBrowserDialog.SelectedPath = textBoxResourcesSource.Text;
            if (folderBrowserDialog.ShowDialog() == DialogResult.OK)
            {
                textBoxResourcesSource.Text = folderBrowserDialog.SelectedPath;
                SetResourcesGovernor();
            }
        }

        /// <summary>
        /// SetResourcesGovernor sets the internal resources governor
        /// </summary>
        protected virtual void SetResourcesGovernor()
        {
            resourcesGovernor = ResourceAdministrationHelper.CreateResourcesGovernor(ResourcesGovernorClassName, Source);
            buttonFolderBrowserDialog.Enabled = resourcesGovernor.IsFileBased;
        }

        private void comboBoxResourcesGovernorClassName_SelectedIndexChanged(object sender, System.EventArgs e)
        {
            SetResourcesGovernor();
        }

        /// <summary>
        /// ResourcesGovernorClassName is the name of the class of the resources governor
        /// </summary>
        public string ResourcesGovernorClassName
        {
            get {return comboBoxResourcesGovernorClassName.Text;}
            set {comboBoxResourcesGovernorClassName.Text = value;}
        }
        /// <summary>
        /// Source is the source of the resources
        /// </summary>
        /// <remarks>The exact contents of Source depends on the ResourcesGovernorClassName. For file
        /// based resource governors this is a path. For database based resource governors this is a
        /// connection string.</remarks>
        public string Source
        {
            get {return textBoxResourcesSource.Text;}
            set {textBoxResourcesSource.Text = value;}
        }
        /// <summary>
        /// TargetLanguage is the ISO 639 language code of the target resources (e.g. "fr")
        /// </summary>
        public string TargetLanguage
        {
            get {return textBoxTargetLanguage.Text;}
            set {textBoxTargetLanguage.Text = value;}
        }

        private void textBoxResourcesSource_Leave(object sender, EventArgs e)
        {
            SetResourcesGovernor();
        }
        /// <summary>
        /// Initialize initializes the internal resource governor
        /// </summary>
        public virtual void Initialize()
        {
            SetResourcesGovernor();
        }
    }
}
