﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Windows.Markup;
using System.Reflection;
using System.Windows;

[assembly: System.Windows.Markup.XmlnsDefinition("http://schemas.microsoft.com/winfx/2006/xaml/presentation", "ResourceMarkupExtensions")]
[assembly: System.Windows.Markup.XmlnsDefinition("http://schemas.microsoft.com/winfx/2007/xaml/presentation", "ResourceMarkupExtensions")]
[assembly: System.Windows.Markup.XmlnsDefinition("http://schemas.microsoft.com/winfx/2008/xaml/presentation", "ResourceMarkupExtensions")]

namespace ResourceMarkupExtensions
{
    [MarkupExtensionReturnType(typeof(object))]
    [ContentProperty("Property")]
    public class ResourceExtension: MarkupExtension
    {
        public string Property { get; set; }

        public ResourceExtension()
        {
        }
        public ResourceExtension(string property)
        {
            Property = property;
        }
        public override object ProvideValue(IServiceProvider serviceProvider)
        {
            return GetValue();
        }
        protected object GetValue()
        {
            if (TypeName == null || PropertyName == null)
                return Property;

            Assembly assembly = GetAssembly();
            Type type = assembly.GetType(assembly.GetName().Name + "." + TypeName);
            PropertyInfo propertyInfo =
                type.GetProperty(PropertyName, BindingFlags.Static | BindingFlags.Public);
            if (propertyInfo == null)
                return Property;

            object value = propertyInfo.GetValue(null, new object[] { });
            return value;
        }
        protected Assembly GetAssembly()
        {
            Assembly assembly = Assembly.GetEntryAssembly();
            if (assembly == null)
            {
                // the markup extension is being executed by the Visual Studio IDE
                Assembly[] currentDomainAssemblies = AppDomain.CurrentDomain.GetAssemblies();
                foreach (Assembly currentDomainAssembly in currentDomainAssemblies)
                {
                    if (currentDomainAssembly.EntryPoint != null)
                    {
                        // the assembly is an executable assembly
                        Type type = currentDomainAssembly.GetType(
                            currentDomainAssembly.GetName().Name + ".App", false);
                        if (type != null && typeof(System.Windows.Application).IsAssignableFrom(type))
                        {
                            // the assembly contains an "App" class that inherits from Application
                            assembly = currentDomainAssembly;
                            break;
                        }
                    }
                }
            }
            return assembly;
        }
        protected string TypeName
        {
            get
            {
                string[] propertyBits = Property.Split('.');
                if (propertyBits.GetLength(0) != 2)
                    return null;

                return propertyBits[0];
            }
        }
        protected string PropertyName
        {
            get
            {
                string[] propertyBits = Property.Split('.');
                if (propertyBits.GetLength(0) != 2)
                    return null;

                return propertyBits[1];
            }
        }
    }
}
