﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Windows;
using System.Windows.Markup;

namespace ResourceMarkupExtensions
{
    public class ResourceWithRefreshExtension: ResourceExtension
    {
        private static List<ResourceWithRefreshExtension> resourceWithRefreshExtensions =
            new List<ResourceWithRefreshExtension>();

        private DependencyProperty targetProperty;
        private WeakReference targetObjectWeakReference;

        public ResourceWithRefreshExtension(string property)
            : base(property)
        {
            resourceWithRefreshExtensions.Add(this);
        }
        public override object ProvideValue(IServiceProvider serviceProvider)
        {
            IProvideValueTarget provideValueTarget = serviceProvider.GetService(
                typeof(IProvideValueTarget)) as IProvideValueTarget;

            if (provideValueTarget != null && provideValueTarget.TargetObject is DependencyObject)
            {
                if ((provideValueTarget.TargetProperty as DependencyProperty) != null)
                {
                    targetProperty = provideValueTarget.TargetProperty as DependencyProperty;
                    targetObjectWeakReference = new WeakReference(provideValueTarget.TargetObject);
                }
            }

            return base.ProvideValue(serviceProvider);
        }
        public void Refresh()
        {
            DependencyObject targetObject = targetObjectWeakReference.Target as DependencyObject;
            if (targetObject != null)
                targetObject.SetValue(targetProperty, GetValue());
        }
        public static void RefreshAll()
        {
            foreach (ResourceWithRefreshExtension resourceWithRefreshExtension in resourceWithRefreshExtensions)
            {
                resourceWithRefreshExtension.Refresh();
            }
        }
    }
}
